@@ -34,7 +34,7 @@ HttpCore::HttpCore()
 
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -152,7 +152,7 @@ void HttpCore::httpRequestFinished(int requestId, bool error){
         xmlreply=http->readAll();
 
 #ifdef DEBUG
-        qDebug()<<"[ii] Recived page:"<<xmlreply;
+        qDebug()<<"[ii] Received page:"<<xmlreply;
 #endif
         emit(pageReaded());
     }
