@@ -22,7 +22,7 @@
 Registry::Registry(){
 	// Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -109,13 +109,13 @@ bool Registry::exec(QObject *parent, QString prefix_path, QString prefix_name){
         QDir dir(prefix_path);
 
         if (!dir.exists()){
-            qDebug()<<"[ee] Fake drive dir do not exists!";
+            qDebug()<<"[ee] Fake drive dir does not exist!";
             return false;
         } else {
             dir.setPath(QString("%1/drive_c/temp").arg(dir.path()));
             if (!dir.exists()){
                 if (!dir.mkdir(dir.path())){
-                    qDebug()<<"[ee] Can't create tmp dir for fake drive dir!";
+                    qDebug()<<"[ee] Cannot create tmp dir for fake drive dir!";
                     return false;
                 }
             }
@@ -148,7 +148,7 @@ QStringList Registry::readKeys(const QString sysfile, const QString path, const
 	QString searchPath;
 
 	for (int i=0; i<keys.count(); i++){
-		ret.append("");
+                ret.append(QString::null);
 	}
 
 	searchPath="[";
@@ -162,7 +162,7 @@ QStringList Registry::readKeys(const QString sysfile, const QString path, const
 
 	QFile file(sfile);
 	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-		qDebug()<<" [EE] Can't open reg file: "<<regfile;
+		qDebug()<<" [EE] Cannot open reg file: "<<regfile;
 		return ret;
 	}
 
@@ -185,6 +185,7 @@ QStringList Registry::readKeys(const QString sysfile, const QString path, const
 		if (((line=="\n") or (line.isEmpty())) and (readFlag))
 			readFlag=false;
 	}
+
 	return ret;
 }
 
@@ -203,7 +204,7 @@ QStringList Registry::readExcludedKeys(const QString sysfile, const QString path
 
 	QFile file(sfile);
 	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-		qDebug()<<" [EE] Can't open reg file: "<<regfile;
+		qDebug()<<" [EE] Cannot open reg file: "<<regfile;
 		return ret;
 	}
 
