@@ -48,6 +48,7 @@
 int main(int argc, char *argv[])
 {
     QtSingleApplication app(argc, argv);
+
     QTextStream QErr(stderr);
 
     QString exec_binary;
@@ -62,7 +63,7 @@ int main(int argc, char *argv[])
     if (app.sendMessage(""))
         return 0;
 
-    //! This is need for libq4wine-core.so import;
+    //! This is needed for libq4wine-core.so import;
     typedef void *CoreLibPrototype (bool);
     CoreLibPrototype *CoreLibClassPointer;
     std::auto_ptr<corelib> CoreLib;
@@ -70,10 +71,11 @@ int main(int argc, char *argv[])
 
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
+
     if (!libq4wine.load()){
         qDebug()<<libq4wine.errorString();
         libq4wine.load();
@@ -84,16 +86,20 @@ int main(int argc, char *argv[])
     CoreLib.reset((corelib *)CoreLibClassPointer(true));
 
     if (!CoreLib.get()){
-        QErr<<"[EE] Can't load shared library."<<endl;
+        QErr<<"[EE] Cannot load shared library."<<endl;
         return -1;
     }
 
     QTranslator qtt;
 
 #ifdef RELEASE
-    QString i18nPath = QString("%1/share/%2/i18n").arg(APP_PREF).arg(APP_SHORT_NAME);
+    #ifdef _OS_DARWIN_
+        QString i18nPath = QString("%1/%2.app/Contents/i18n").arg(QDir::currentPath()).arg(APP_SHORT_NAME);
+    #else
+        QString i18nPath = QString("%1/share/%2/i18n").arg(QString::fromUtf8(APP_PREF)).arg(APP_SHORT_NAME);
+    #endif
 #else
-    QString i18nPath = QString("%1/i18n").arg(APP_BUILD);
+    QString i18nPath = QString("%1/i18n").arg(QString::fromUtf8(APP_BUILD));
 #endif
 
 
@@ -107,14 +113,14 @@ int main(int argc, char *argv[])
     DataBase db;
 
     if (!db.checkDb()){
-        QErr<<"[EE] Can't init database engine."<<endl;
+        QErr<<"[EE] Cannot initialize database engine."<<endl;
         return -1;
     }
 
     if (!CoreLib->isConfigured()){
         Wizard firstSetupWizard(1);
         if (firstSetupWizard.exec()==QDialog::Rejected){
-            QErr<<"[EE] App not configured! Re run wizard, or delete q4wine broken config files."<<endl;
+            QErr<<"[EE] Application not configured! Rerun the setup wizard or delete broken Q4Wine configuration files."<<endl;
             return -1;
         }
     }
@@ -140,15 +146,15 @@ int main(int argc, char *argv[])
             Qcout<<QObject::tr("Usage:")<<endl;
             Qcout<<QString("  %1 -b <unix_path_to_windown_binary>").arg(APP_SHORT_NAME)<<endl;
             Qcout<<QObject::tr("  %1 [KEY]...").arg(APP_SHORT_NAME)<<endl;
-            Qcout<<QObject::tr("GUI utility for wine applications and prefixes management.")<<endl<<endl;
+            Qcout<<QObject::tr("GUI utility for Wine applications and prefixes management.")<<endl<<endl;
             Qcout<<QObject::tr("KEYs list:")<<endl;
             Qcout<<qSetFieldWidth(25)<<left<<"  -h,  --help"<<QObject::tr("display this help and exit")<<qSetFieldWidth(0)<<endl;
             Qcout<<qSetFieldWidth(25)<<left<<"  -v,  --version"<<QObject::tr("output version information and exit")<<qSetFieldWidth(0)<<endl;
-            Qcout<<qSetFieldWidth(25)<<left<<"  -b,  --binary"<<QObject::tr("Open q4wine run dialog for windows binary")<<qSetFieldWidth(0)<<endl;
+            Qcout<<qSetFieldWidth(25)<<left<<"  -b,  --binary"<<QObject::tr("open Q4Wine run dialog for Windows binary")<<qSetFieldWidth(0)<<endl;
             Qcout<<qSetFieldWidth(25)<<left<<"  -m,  --minimize"<<QObject::tr("minimize %1 main window on startup").arg(APP_SHORT_NAME)<<qSetFieldWidth(0)<<endl;
             Qcout<<endl;
             Qcout<<QObject::tr("Report %1 bugs to %2").arg(APP_SHORT_NAME).arg(APP_BUG_EMAIL)<<endl;
-            Qcout<<QObject::tr("%1 homepage: <%2>").arg(APP_SHORT_NAME).arg(APP_WEBSITTE)<<endl;
+            Qcout<<QObject::tr("%1 homepage: <%2>").arg(APP_SHORT_NAME).arg(APP_WEBSITE)<<endl;
             Qcout<<QObject::tr("General help using GNU software: <http://www.gnu.org/gethelp/>")<<endl;
             return 0;
         }
