@@ -24,35 +24,28 @@
 
 #include "config.h"
 
-#include "src/q4wine-gui/ui_winetricks.h"
-
+#include <QString>
 #include <QStringList>
 #include <QProcess>
 #include <QMessageBox>
 #include <QLibrary>
-#include <QKeyEvent>
-#include <QEvent>
+#include <QProgressDialog>
+
 #include "process.h"
 
 #include "prefix.h"
+#include "sysconfig.h"
 
 #include "q4wine-lib.h"
 
-class winetricks : public QDialog, public Ui::winetricks {
-    Q_OBJECT
-    Q_DISABLE_COPY(winetricks)
+class winetricks : public QWidget{
+
 public:
-    winetricks(QString prefixName, QWidget * parent = 0, Qt::WFlags f = 0);
-    QString _prefixName;
-
-protected:
-    bool eventFilter(QObject *obj, QEvent *event);
-
-private slots:
-    void lstMain_itemClicked(QListWidgetItem* item);
-    void run_winetricks();
+    winetricks(QString prefix_name);
+    void run_winetricks(QString item);
     void install_winetricks();
     bool parse();
+
 private:
     //! This is need for libq4wine-core.so import;
     typedef void *CoreLibPrototype (bool);
@@ -62,20 +55,18 @@ private:
     QLibrary libq4wine;
 
     Prefix db_prefix;
+    Sysconfig db_sysconfig;
 
     QString console_bin;
     QString console_args;
     QString prefix_name;
     QString winetricks_bin;
 
+    QStringList subtypes;
+
     void downloadwinetricks();
-    void removefile(QString);
-
-    void addToList (QString arg);
-
-    QStringList names;
-    QStringList descs;
-
+    bool check_script(bool warn = true);
+    QStringList get_stdout_lines(QString command);
 };
 
 #endif // WINETRICKS_H
