@@ -23,7 +23,7 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -69,6 +69,7 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     cmdGetWineServerBin->installEventFilter(this);
     cmdGetWineLoaderBin->installEventFilter(this);
     cmdGetWineLibs->installEventFilter(this);
+    cmdGetWineLibs64->installEventFilter(this);
     cmdGetTarBin->installEventFilter(this);
     cmdGetMountBin->installEventFilter(this);
     cmdGetUmountBin->installEventFilter(this);
@@ -78,6 +79,7 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     cmdGetReniceBin->installEventFilter(this);
     cmdGetConsoleBin->installEventFilter(this);
     cmdGetShBin->installEventFilter(this);
+    cmdGetDefPrefixPath->installEventFilter(this);
 
     QSettings settings(APP_SHORT_NAME, "default");
 
@@ -85,17 +87,11 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     txtWineBin->setText(settings.value("WineBin").toString());
     txtWineServerBin->setText(settings.value("ServerBin").toString());
     txtWineLoaderBin->setText(settings.value("LoaderBin").toString());
-    txtWineLibs->setText(settings.value("WineLibs").toString());
+    txtWineLibs->setText(settings.value("WineLibs32").toString());
+    txtWineLibs64->setText(settings.value("WineLibs64").toString());
     settings.endGroup();
 
     settings.beginGroup("logging");
-    if (settings.value("enable", 0).toInt()==1){
-        cbEnableLogging->setCheckState(Qt::Checked);
-    } else {
-        cbEnableLogging->setCheckState(Qt::Unchecked);
-    }
-
-    connect (cbEnableLogging, SIGNAL(stateChanged (int)), this, SLOT(cbEnableLogging_stateChanged (int)));
     connect (cbShowTray, SIGNAL(stateChanged (int)), this, SLOT(cbShowTray_stateChanged (int)));
 
     if (settings.value("autoClear", 1).toInt()==1){
@@ -139,6 +135,7 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     listThemesView->setSelectionMode(QAbstractItemView::SingleSelection);
 
     QString themeDir="";
+
     themeDir.append(QDir::homePath());
     themeDir.append("/.config/");
     themeDir.append(APP_SHORT_NAME);
@@ -154,10 +151,18 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     }
 
     themeDir.clear();
-    themeDir.append(APP_PREF);
+
+#ifdef _OS_DARWIN_
+    themeDir.append(QDir::currentPath());
+    themeDir.append("/");
+    themeDir.append(APP_SHORT_NAME);
+    themeDir.append(".app/Contents/Resources/theme");
+#else
+    themeDir.append(QString::fromUtf8(APP_PREF));
     themeDir.append("/share/");
     themeDir.append(APP_SHORT_NAME);
     themeDir.append("/theme");
+#endif
 
     getThemes(settings.value("theme").toString(), themeDir);
 
@@ -229,8 +234,18 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     this->comboMountProfiles->removeItem(3);
     this->comboMountProfiles->removeItem(2);
 #endif
+#ifdef _OS_DARWIN_
+    this->comboMountProfiles->removeItem(3);
+    this->comboMountProfiles->removeItem(2);
+    this->comboMountProfiles->removeItem(1);
+    this->comboMountProfiles->setItemText(0, tr("generic"));
+    this->txtMountString->setEnabled(false);
+    this->frameMount->setVisible(false);
+#endif
 
     settings.beginGroup("advanced");
+    txtDefPrefixPath->setText(settings.value("prefixDefaultPath").toString());
+
     if (settings.value("openRunDialog", 0).toInt()==0){
         cbOpenRunDialog->setChecked(false);
     } else {
@@ -285,14 +300,21 @@ AppSettings::AppSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     }
     settings.endGroup();
 
-    settings.beginGroup("Interface");
-    if (settings.value("expandPrefixTree", 1).toInt()==1){
-        cbExpandPrefixTree->setChecked(true);
+#ifndef _OS_DARWIN_
+    settings.beginGroup("Plugins");
+    if (settings.value("enableMenuDesktop", 1).toInt()==1){
+        cbEnableDesktopMenu->setChecked(true);
     } else {
-        cbExpandPrefixTree->setChecked(false);
+        cbEnableDesktopMenu->setChecked(false);
     }
     settings.endGroup();
-
+    connect(cmdDesktopMenu_Regen, SIGNAL(clicked()), this, SLOT(cmdDesktopMenu_Regen_Click()));
+    connect(cmdDesktopMenu_Remove, SIGNAL(clicked()), this, SLOT(cmdDesktopMenu_Remove_Click()));
+#else
+    cbEnableDesktopMenu->setEnabled(false);
+    cmdDesktopMenu_Regen->setEnabled(false);
+    cmdDesktopMenu_Remove->setEnabled(false);
+#endif
 
     QList<QTreeWidgetItem *> items = optionsTree->findItems (tr("General"), Qt::MatchExactly);
     if (items.count()>0){
@@ -334,23 +356,23 @@ void AppSettings::optionsTree_itemClicked ( QTreeWidgetItem *item, int){
         tabwInterface->setCurrentIndex(0);
     } else if (itemText==tr("Language")){
         optionsStack->setCurrentIndex(1);
-        tabwInterface->setCurrentIndex(1);
+        tabwInterface->setCurrentIndex(0);
     } else if (itemText==tr("Themes")){
         optionsStack->setCurrentIndex(1);
-        tabwInterface->setCurrentIndex(2);
+        tabwInterface->setCurrentIndex(1);
     } else if (itemText==tr("Subsystems")){
         optionsStack->setCurrentIndex(2);
         tabwInterface->setCurrentIndex(0);
     } else if (itemText==tr("Logging")){
         optionsStack->setCurrentIndex(2);
         tabwSubsystems->setCurrentIndex(0);
-    } else if (itemText==tr("AppDb browser")){
+    } else if (itemText==tr("AppDB browser")){
         optionsStack->setCurrentIndex(2);
         tabwSubsystems->setCurrentIndex(1);
     } else if (itemText==tr("Plugins")){
         optionsStack->setCurrentIndex(3);
         tabwPlugins->setCurrentIndex(1);
-    } else if (itemText==tr("Winetricks")){
+    } else if (itemText==tr("Desktop Menu")){
         optionsStack->setCurrentIndex(3);
         tabwPlugins->setCurrentIndex(1);
     } else if (itemText==tr("Advanced")){
@@ -436,11 +458,18 @@ void AppSettings::comboProxyType_indexChanged(QString text){
 void AppSettings::getLangs(){
     QString themeDir="";
 #ifdef RELEASE
-    themeDir = APP_PREF;
-    themeDir.append("/share/");
-    themeDir.append(APP_SHORT_NAME);
+    #ifdef _OS_DARWIN_
+        themeDir = QDir::currentPath();
+        themeDir.append("/");
+        themeDir.append(APP_SHORT_NAME);
+        themeDir.append(".app/Contents");
+    #else
+        themeDir = APP_PREF;
+        themeDir.append("/share/");
+        themeDir.append(APP_SHORT_NAME);
+    #endif
 #else
-    themeDir = APP_BUILD;
+    themeDir = QString::fromUtf8(APP_BUILD);
 #endif
     themeDir.append("/i18n");
 
@@ -507,6 +536,7 @@ void AppSettings::loadThemeIcons(){
     cmdGetWineServerBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetWineLoaderBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetWineLibs->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetWineLibs64->setIcon(CoreLib->loadIcon("data/folder.png"));
 
     cmdGetTarBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetMountBin->setIcon(CoreLib->loadIcon("data/folder.png"));
@@ -520,6 +550,7 @@ void AppSettings::loadThemeIcons(){
     cmdGetConsoleBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetWrestoolBin->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetIcotoolBin->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetDefPrefixPath->setIcon(CoreLib->loadIcon("data/folder.png"));
     return;
 }
 
@@ -529,7 +560,6 @@ void AppSettings::cmdCancel_Click(){
 }
 
 void AppSettings::cmdOk_Click(){
-
     if (!checkEntry(txtWineBin->text(), "wine"))
         return;
 
@@ -594,17 +624,12 @@ void AppSettings::cmdOk_Click(){
     settings.setValue("WineBin", txtWineBin->text());
     settings.setValue("ServerBin", txtWineServerBin->text());
     settings.setValue("LoaderBin", txtWineLoaderBin->text());
-    settings.setValue("WineLibs", txtWineLibs->text());
+    settings.setValue("WineLibs32", txtWineLibs->text());
+    settings.setValue("WineLibs64", txtWineLibs64->text());
     settings.endGroup();
 
     settings.beginGroup("logging");
-    if (cbEnableLogging->checkState()==Qt::Checked) {
-        settings.setValue("enable", 1);
-    } else {
-        settings.setValue("enable", 0);
-    }
-
-    if ((cbClearLogs->checkState()==Qt::Checked) and (cbEnableLogging->checkState()==Qt::Checked)) {
+    if (cbClearLogs->checkState()==Qt::Checked) {
         settings.setValue("autoClear", 1);
     } else {
         settings.setValue("autoClear", 0);
@@ -699,6 +724,7 @@ void AppSettings::cmdOk_Click(){
     settings.endGroup();
 
     settings.beginGroup("advanced");
+    settings.setValue("prefixDefaultPath", txtDefPrefixPath->text());
     if (cbOpenRunDialog->isChecked()){
         settings.setValue("openRunDialog", 1);
     } else {
@@ -748,15 +774,15 @@ void AppSettings::cmdOk_Click(){
         settings.setValue("useSystemBrowser", 0);
     }
     settings.endGroup();
-
-    settings.beginGroup("Interface");
-    if (cbExpandPrefixTree->isChecked()){
-        settings.setValue("expandPrefixTree", 1);
+#ifndef _OS_DARWIN_
+    settings.beginGroup("Plugins");
+    if (cbEnableDesktopMenu->isChecked()){
+        settings.setValue("enableMenuDesktop", 1);
     } else {
-        settings.setValue("expandPrefixTree", 0);
+        settings.setValue("enableMenuDesktop", 0);
     }
-
     settings.endGroup();
+#endif
 
     accept();
     return;
@@ -781,10 +807,10 @@ bool AppSettings::checkEntry(QString fileName, QString info, bool isFile){
         if (!QFile::exists(fileName)){
             switch (isFile){
    case FALSE:
-                QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 directory not exists.").arg(info));
+                QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 directory does not exist.").arg(info));
                 break;
    case TRUE:
-                QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 binary not exists.").arg(info));
+                QMessageBox::warning(this, tr("Error"), tr("Sorry, specified %1 binary does not exist.").arg(info));
                 break;
             }
             return FALSE;
@@ -825,12 +851,12 @@ void AppSettings::cmdHelp_Click(){
         rawurl = "11-settings.html#logging";
     } else if (itemText==tr("Logging")){
         rawurl = "11-settings.html#logging";
-    } else if (itemText==tr("AppDb browser")){
+    } else if (itemText==tr("AppDB browser")){
         rawurl = "11-settings.html#appdb";
     } else if (itemText==tr("Plugins")){
-        rawurl = "11-settings.html";
-    } else if (itemText==tr("Winetricks")){
-        rawurl = "11-settings.html";
+        rawurl = "11-settings.html#plugins";
+    } else if (itemText==tr("Desktop Menu")){
+        rawurl = "11-settings.html#desktopmenu";
     } else if (itemText==tr("Advanced")){
         rawurl = "11-settings.html#defaults";
     } else if (itemText==tr("Defaults")){
@@ -866,15 +892,6 @@ void AppSettings::comboMountProfiles_currentIndexChanged(int index){
     txtUmountString->setText(CoreLib->getUmountString(index));
 }
 
-void AppSettings::cbEnableLogging_stateChanged ( int state ){
-    if (state==0){
-        cbClearLogs->setEnabled(false);
-    } else {
-        cbClearLogs->setEnabled(true);
-    }
-}
-
-
 void AppSettings::cbShowTray_stateChanged ( int state ){
     if (state==0){
         cbShowNotifications->setEnabled(false);
@@ -883,3 +900,13 @@ void AppSettings::cbShowTray_stateChanged ( int state ){
     }
 }
 
+void AppSettings::cmdDesktopMenu_Regen_Click(){
+    system_menu sys_menu;
+    sys_menu.create_dir_info();
+    sys_menu.generateSystemMenu();
+}
+
+void AppSettings::cmdDesktopMenu_Remove_Click(){
+    system_menu sys_menu;
+    sys_menu.wipeSystemMenu();
+}
