@@ -23,7 +23,7 @@ FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::W
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -232,31 +232,22 @@ void FakeDriveSettings::cmdOk_Click(){
 
     QString prefixPath = db_prefix.getPath(prefixName);
 
-    /*
-     * Wine wan't create prefix for different ARCH while empty directory exists
-     * so we try to delete empty directory.
-     *
-     * Note: This will not delete an un empty directory
-     */
-
     QDir dir;
     QFile file;
     QFileInfo fileInfo;
 
-    dir.remove(prefixPath);
-
     QString userDir = prefixPath;
     userDir.append("/drive_c/users/");
-    userDir.append(getenv("USER"));
+    userDir.append(QString::fromUtf8(getenv("USER")));
 
     if (list.count()==5){
                 desktopFolder = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(0).split("\\\\").last()));
-                desktopDocuments = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(1).split("\\\\").last()));
-                desktopMusic = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(2).split("\\\\").last()));
-                desktopPictures = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(3).split("\\\\").last()));
-                desktopVideos = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(4).split("\\\\").last()));
+                desktopMusic = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(1).split("\\\\").last()));
+                desktopPictures = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(2).split("\\\\").last()));
+                desktopDocuments = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(4).split("\\\\").last()));
+                desktopVideos = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(3).split("\\\\").last()));
     } else {
-         QMessageBox::warning(this, tr("Error"), tr("Can't read desktop paths!"));
+         QMessageBox::warning(this, tr("Error"), tr("Cannot read desktop paths!"));
         this->reject();
         return;
     }
@@ -282,7 +273,7 @@ void FakeDriveSettings::cmdOk_Click(){
             QFileInfo fileInfo = drivelist.at(i);
             if (fileInfo.isSymLink()){
                             if (!file.remove(fileInfo.filePath())){
-                                QMessageBox::warning(this, tr("Error"), tr("Can't remove symlink: %1").arg(fileInfo.filePath()));
+                                QMessageBox::warning(this, tr("Error"), tr("Cannot remove symlink: %1").arg(fileInfo.filePath()));
                                 QApplication::restoreOverrideCursor();
                                 reject();
                             }
@@ -297,7 +288,7 @@ void FakeDriveSettings::cmdOk_Click(){
             if (item.get()){
                             QString driveLink = QString("%1/%2").arg(prefixPath).arg(item->getLetter().toLower());
                             if (!file.link(item->getPath(), driveLink)){
-                                QMessageBox::warning(this, tr("Error"), tr("Can't symlink \"%1\" to \"%2\"").arg(item->getPath()).arg(driveLink));
+                                QMessageBox::warning(this, tr("Error"), tr("Cannot symlink \"%1\" to \"%2\"").arg(item->getPath()).arg(driveLink));
                                 QApplication::restoreOverrideCursor();
                                 reject();
                                 return;
@@ -310,7 +301,7 @@ void FakeDriveSettings::cmdOk_Click(){
         // Check and create user path
         if (!dir.exists(prefixPath)){
             if (!dir.mkdir(prefixPath)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't create dir: %1").arg(prefixPath));
+                QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
@@ -321,23 +312,25 @@ void FakeDriveSettings::cmdOk_Click(){
         fileInfo.setFile(desktopFolder);
         if (fileInfo.isSymLink() || fileInfo.exists()){
             if (!dir.remove(desktopFolder)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't remove dir: %1").arg(desktopFolder));
+                QMessageBox::warning(this, tr("Error"), tr("Cannot remove dir: %1").arg(desktopFolder));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
             }
         }
 
-        if (txtWineDesktop->text().isEmpty()){
+        if (!txtWineDesktop->text().isEmpty()){
+            /*
+            file.setFileName(desktopFolder);
             if (!file.open(QIODevice::WriteOnly)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't create file \"%1\"").arg(desktopFolder));
+                QMessageBox::warning(this, tr("Error"), tr("Cannot create file \"%1\"").arg(desktopFolder));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
             }
-        } else {
+        } else {*/
             if (!file.link(txtWineDesktop->text(), desktopFolder)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't symlink \"%1\" to \"%2\"").arg(txtWineDesktop->text()).arg(desktopFolder));
+                QMessageBox::warning(this, tr("Error"), tr("Cannot symlink \"%1\" to \"%2\"").arg(txtWineDesktop->text()).arg(desktopFolder));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
@@ -345,77 +338,85 @@ void FakeDriveSettings::cmdOk_Click(){
         }
 
         // Doc folder
-        fileInfo.setFile(desktopDocuments);
-        if (fileInfo.isSymLink() || fileInfo.exists()){
-            if (!dir.remove(desktopDocuments)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't remove dir: %1").arg(desktopDocuments));
+        if (!txtWineDesktopDoc->text().isEmpty()){
+            fileInfo.setFile(desktopDocuments);
+            if (fileInfo.isSymLink() || fileInfo.exists()){
+                if (!dir.remove(desktopDocuments)){
+                    QMessageBox::warning(this, tr("Error"), tr("Cannot remove dir: %1").arg(desktopDocuments));
+                    QApplication::restoreOverrideCursor();
+                    reject();
+                    return;
+                }
+            }
+
+            if (!file.link(txtWineDesktopDoc->text(), desktopDocuments)){
+                QMessageBox::warning(this, tr("Error"), tr("Cannot symlink \"%1\" to \"%2\"").arg(txtWineDesktopDoc->text()).arg(desktopDocuments));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
             }
         }
 
-        if (!file.link(txtWineDesktopDoc->text(), desktopDocuments)){
-            QMessageBox::warning(this, tr("Error"), tr("Can't symlink \"%1\" to \"%2\"").arg(txtWineDesktopDoc->text()).arg(desktopDocuments));
-            QApplication::restoreOverrideCursor();
-            reject();
-            return;
-        }
-
         // Music folder
-        fileInfo.setFile(desktopMusic);
-        if (fileInfo.isSymLink() || fileInfo.exists()){
-            if (!dir.remove(desktopMusic)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't remove dir: %1").arg(desktopMusic));
+        if (!txtWineDesktopMus->text().isEmpty()){
+            fileInfo.setFile(desktopMusic);
+            if (fileInfo.isSymLink() || fileInfo.exists()){
+                if (!dir.remove(desktopMusic)){
+                    QMessageBox::warning(this, tr("Error"), tr("Cannot remove dir: %1").arg(desktopMusic));
+                    QApplication::restoreOverrideCursor();
+                    reject();
+                    return;
+                }
+            }
+
+            if (!file.link(txtWineDesktopMus->text(), desktopMusic)){
+                QMessageBox::warning(this, tr("Error"), tr("Cannot symlink \"%1\" to \"%2\"").arg(txtWineDesktopMus->text()).arg(desktopMusic));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
             }
         }
 
-        if (!file.link(txtWineDesktopMus->text(), desktopMusic)){
-            QMessageBox::warning(this, tr("Error"), tr("Can't symlink \"%1\" to \"%2\"").arg(txtWineDesktopMus->text()).arg(desktopMusic));
-            QApplication::restoreOverrideCursor();
-            reject();
-            return;
-        }
-
         // Pic folder
-        fileInfo.setFile(desktopPictures);
-        if (fileInfo.isSymLink() || fileInfo.exists()){
-            if (!dir.remove(desktopPictures)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't remove dir: %1").arg(desktopPictures));
+        if (!txtWineDesktopPic->text().isEmpty()){
+            fileInfo.setFile(desktopPictures);
+            if (fileInfo.isSymLink() || fileInfo.exists()){
+                if (!dir.remove(desktopPictures)){
+                    QMessageBox::warning(this, tr("Error"), tr("Cannot remove dir: %1").arg(desktopPictures));
+                    QApplication::restoreOverrideCursor();
+                    reject();
+                    return;
+                }
+            }
+
+            if (!file.link(txtWineDesktopPic->text(), desktopPictures)){
+                QMessageBox::warning(this, tr("Error"), tr("Cannot symlink \"%1\" to \"%2\"").arg(txtWineDesktopPic->text()).arg(desktopPictures));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
             }
         }
 
-        if (!file.link(txtWineDesktopPic->text(), desktopPictures)){
-            QMessageBox::warning(this, tr("Error"), tr("Can't symlink \"%1\" to \"%2\"").arg(txtWineDesktopPic->text()).arg(desktopPictures));
-            QApplication::restoreOverrideCursor();
-            reject();
-            return;
-        }
-
         // Vid folder
-        fileInfo.setFile(desktopVideos);
-        if (fileInfo.isSymLink() || fileInfo.exists()){
-            if (!dir.remove(desktopVideos)){
-                QMessageBox::warning(this, tr("Error"), tr("Can't remove dir: %1").arg(desktopVideos));
+        if (!txtWineDesktopVid->text().isEmpty()){
+            fileInfo.setFile(desktopVideos);
+            if (fileInfo.isSymLink() || fileInfo.exists()){
+                if (!dir.remove(desktopVideos)){
+                    QMessageBox::warning(this, tr("Error"), tr("Cannot remove dir: %1").arg(desktopVideos));
+                    QApplication::restoreOverrideCursor();
+                    reject();
+                    return;
+                }
+            }
+
+            if (!file.link(txtWineDesktopVid->text(), desktopVideos)){
+                QMessageBox::warning(this, tr("Error"), tr("Cannot symlink \"%1\" to \"%2\"").arg(txtWineDesktopVid->text()).arg(desktopVideos));
                 QApplication::restoreOverrideCursor();
                 reject();
                 return;
             }
         }
 
-        if (!file.link(txtWineDesktopVid->text(), desktopVideos)){
-            QMessageBox::warning(this, tr("Error"), tr("Can't symlink \"%1\" to \"%2\"").arg(txtWineDesktopVid->text()).arg(desktopVideos));
-            QApplication::restoreOverrideCursor();
-            reject();
-            return;
-        }
-
     // ---- End of Creating Dos drives ----
 
     Registry registry;
@@ -759,6 +760,13 @@ void FakeDriveSettings::cmdOk_Click(){
 
         if (registry.exec(this, db_prefix.getPath(prefixName), prefixName)){
         CoreLib->createPrefixDBStructure(prefixName);
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+            system_menu sys_menu;
+            sys_menu.generateSystemMenu(prefixName);
+        }
+#endif
+
 #ifdef DEBUG
     qDebug()<<"[ii] Wizard::done";
 #endif
@@ -777,14 +785,17 @@ void FakeDriveSettings::waitForWineEnd(){
 
 void FakeDriveSettings::waitForWine(){
     QString prefixPath = db_prefix.getPath(this->prefixName);
+    QString sysRegPath = QString("%1/%2").arg(prefixPath).arg("system.reg");
+    QString usrRegPath = QString("%1/%2").arg(prefixPath).arg("user.reg");
     QFile file;
 
-    if (file.exists(QString("%1/%2").arg(prefixPath).arg("system.reg")) && file.exists(QString("%1/%2").arg(prefixPath).arg("user.reg"))){
+    if (file.exists(sysRegPath) && file.exists(usrRegPath)){
         QApplication::restoreOverrideCursor();
         this->setEnabled(true);
     } else {
         QTimer::singleShot(1000, this, SLOT(waitForWine()));
     }
+    return;
 }
 
 void FakeDriveSettings::cmdCancel_Click(){
@@ -941,7 +952,7 @@ void FakeDriveSettings::cmdWineDriveDel_Click(){
         return;
 
     if (item->text().left(2)=="C:"){
-        QMessageBox::warning(this, tr("Error"), tr("Sorry, You can't delete or modify wine C: drive.<br>But You can change it in prefix settings dialog."));
+        QMessageBox::warning(this, tr("Error"), tr("Sorry, You cannot delete or modify wine C: drive.<br>But You can change it in prefix settings dialog."));
         item.release();
         return;
     }
@@ -969,12 +980,12 @@ void FakeDriveSettings::loadSettings(){
 
     if (list.count()==5){
         desktopFolder = CoreLib->decodeRegString(list.at(0).split("\\\\").last());
-        desktopDocuments = CoreLib->decodeRegString(list.at(1).split("\\\\").last());
-        desktopMusic = CoreLib->decodeRegString(list.at(2).split("\\\\").last());
-        desktopPictures = CoreLib->decodeRegString(list.at(3).split("\\\\").last());
-        desktopVideos = CoreLib->decodeRegString(list.at(4).split("\\\\").last());
+        desktopMusic = CoreLib->decodeRegString(list.at(1).split("\\\\").last());
+        desktopPictures = CoreLib->decodeRegString(list.at(2).split("\\\\").last());
+        desktopVideos = CoreLib->decodeRegString(list.at(3).split("\\\\").last());
+        desktopDocuments = CoreLib->decodeRegString(list.at(4).split("\\\\").last());
     } else {
-        QMessageBox::warning(this, tr("Error"), tr("Can't read desktop paths!"));
+        QMessageBox::warning(this, tr("Error"), tr("Cannot read desktop paths!"));
         this->reject();
         return;
     }
@@ -1170,7 +1181,9 @@ void FakeDriveSettings::loadSettings(){
     list << "\"Audio\"";
     list = reg.readKeys("user", "Software\\Wine\\Drivers", list);
     if (list.count()>0){
-        if (!list.at(0).isEmpty()){
+        if (list.at(0) == QString::null){
+            comboFakeSound_Driver->setCurrentIndex(comboFakeSound_Driver->findText("default"));
+        } else if (!list.at(0).isEmpty()){
             comboFakeSound_Driver->setCurrentIndex(comboFakeSound_Driver->findText(list.at(0)));
         } else {
             comboFakeSound_Driver->setCurrentIndex(comboFakeSound_Driver->findText("disabled"));
@@ -1233,7 +1246,7 @@ void FakeDriveSettings::loadSettings(){
     }
 
     prefixPath.append("c:/users/");
-    prefixPath.append(getenv("USER"));
+    prefixPath.append(QString::fromUtf8(getenv("USER")));
 
     if (!wineDriveDir.cd(prefixPath)){
         qDebug()<<"Cannot cd to prefix directory: "<<prefixPath;
@@ -1281,8 +1294,12 @@ void FakeDriveSettings::loadSettings(){
 }
 
 void FakeDriveSettings::loadDefaultSettings(){
-        this->setEnabled(false);
-        QApplication::setOverrideCursor( Qt::BusyCursor );
+    this->setEnabled(false);
+    QApplication::setOverrideCursor(Qt::BusyCursor);
+
+    QString prefixPath = db_prefix.getPath(this->prefixName);
+
+    QDir dir;
 
     ExecObject execObj;
     execObj.cmdargs = "-u -i";
@@ -1294,7 +1311,7 @@ void FakeDriveSettings::loadDefaultSettings(){
         return;
     }
 
-    txtOwner->setText(getenv("USER"));
+    txtOwner->setText(QString::fromUtf8(getenv("USER")));
 
     std::auto_ptr<DriveListWidgetItem> item;
     item.reset(new DriveListWidgetItem(listWineDrives));
@@ -1314,19 +1331,15 @@ void FakeDriveSettings::loadDefaultSettings(){
     item->setDrive("Z:", "/", "auto");
     listWineDrives->addItem(item.release());
 
-    QString prefixPath = db_prefix.getPath(this->prefixName);
-
     txtWineDesktop->setText(QString("%1/desktop-integration/Desktop").arg(prefixPath));
     txtWineDesktopDoc->setText(QString("%1/desktop-integration/").arg(prefixPath));
     txtWineDesktopMus->setText(QString("%1/desktop-integration/").arg(prefixPath));
     txtWineDesktopPic->setText(QString("%1/desktop-integration/").arg(prefixPath));
     txtWineDesktopVid->setText(QString("%1/desktop-integration/").arg(prefixPath));
 
-        QDir dir;
-
         if (!dir.exists(txtWineDesktopDoc->text())){
             if (!dir.mkdir(txtWineDesktopDoc->text())){
-                QMessageBox::warning(this, tr("Error"), tr("Can't create dir: %1").arg(prefixPath));
+                QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
                 QApplication::restoreOverrideCursor();
                 reject();
             }
@@ -1334,7 +1347,7 @@ void FakeDriveSettings::loadDefaultSettings(){
 
         if (!dir.exists(txtWineDesktop->text())){
             if (!dir.mkdir(txtWineDesktop->text())){
-                QMessageBox::warning(this, tr("Error"), tr("Can't create dir: %1").arg(prefixPath));
+                QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
                 QApplication::restoreOverrideCursor();
                 reject();
             }
