@@ -33,7 +33,7 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
 
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -102,6 +102,8 @@ IconSettings::IconSettings(QString prefix_name, QString dir_name, QString icon_n
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
     connect(cmdHelp, SIGNAL(clicked()), this, SLOT(cmdHelp_Click()));
+    connect(cmdGetPreRun, SIGNAL(clicked()), this, SLOT(cmdGetPreRun_Click()));
+    connect(cmdGetPostRun, SIGNAL(clicked()), this, SLOT(cmdGetPostRun_Click()));
 
     connect(cbUseConsole, SIGNAL(stateChanged(int)), this, SLOT(cbUseConsole_stateChanged(int)));
 
@@ -120,7 +122,8 @@ void IconSettings::loadThemeIcons(){
     cmdGetProgram->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetWorkDir->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetIcon->setIcon(CoreLib->loadIcon("data/exec_wine.png"));
-
+    cmdGetPreRun->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdGetPostRun->setIcon(CoreLib->loadIcon("data/folder.png"));
     return;
 }
 
@@ -139,24 +142,16 @@ void IconSettings::getIconReccord(){
         if (QFile(iconPath).exists()){
             cmdGetIcon->setIcon (QIcon(iconPath));
         } else {
-            if (iconPath=="console"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/wineconsole.png"));
-            } else if (iconPath=="regedit"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/regedit.png"));
-            } else if (iconPath=="wordpad"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/notepad.png"));
-            } else if (iconPath=="winecfg"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/winecfg.png"));
-            } else if (iconPath=="uninstaller"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/uninstaller.png"));
-            } else if (iconPath=="eject"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/eject.png"));
-            } else if (iconPath=="explorer"){
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/explorer.png"));
-            } else {
-                cmdGetIcon->setIcon(CoreLib->loadIcon("data/exec_wine.png"));
+            QIcon ico = CoreLib->loadIcon(QString("data/%1.png").arg(iconPath));
+
+            // Do not work due to: https://bugreports.qt-project.org/browse/QTBUG-999
+            //if (ico.isNull()){
+            if (ico.availableSizes().isEmpty()){
+                ico = CoreLib->loadIcon("data/exec_wine.png");
                 iconPath="";
             }
+
+            cmdGetIcon->setIcon(ico);
         }
     }
 
@@ -195,17 +190,20 @@ void IconSettings::getIconReccord(){
             if (list2.at(1)=="n")
                 overrideorder = tr("Native");
             if (list2.at(1)=="b")
-                overrideorder = tr("Buildin");
+                overrideorder = tr("Built-in");
             if (list2.at(1)=="n,b")
-                overrideorder = tr("Native, Buildin");
+                overrideorder = tr("Native, Built-in");
             if (list2.at(1)=="b,n")
-                overrideorder = tr("Buildin, Native");
+                overrideorder = tr("Built-in, Native");
 
             newItem.reset(new QTableWidgetItem(overrideorder));
             newItem->setFlags( Qt::ItemIsEnabled | Qt::ItemIsSelectable );
             twDlls->setItem(0, 1, newItem.release());
     }
 
+    txtPreRun->setText(iconRec.value("prerun"));
+    txtPostRun->setText(iconRec.value("postrun"));
+
     return;
 }
 
@@ -423,7 +421,7 @@ void IconSettings::cmdGetIcon_Click(){
         #ifndef WITH_ICOUTILS
         dialog.setNameFilter(tr("Image files (*.png *.jpg *.gif *.bmp *.xpm)"));
         #else
-        dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.jpg *.gif *.bmp *.xpm *.exe *.dll);;Image files (*.png *.jpg *.gif *.bmp *.xpm);;Win32 Executable (*.exe);;Win32 Shared libraies (*.dll);;Win32 Executable and Shared libraies (*.exe *.dll)"));
+        dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.jpg *.gif *.bmp *.xpm *.exe *.dll);;Image files (*.png *.jpg *.gif *.bmp *.xpm);;Win32 Executable (*.exe);;Win32 Shared libraries (*.dll);;Win32 Executable and Shared libraries (*.exe *.dll)"));
         #endif
       //dialog.setSidebarUrls(add_prefix_urls);
 
@@ -456,30 +454,32 @@ void IconSettings::cmdGetIcon_Click(){
                 for (int i = 0; i < list.size(); ++i) {
                     QFileInfo fileInfo = list.at(i);
                     if (!tmp.remove(fileInfo.filePath()))
-                        qDebug()<<"[EE] - Can't delete files at: "<<fileInfo.filePath();
+                        qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
                 }
             } else {
                 if (!tmp.mkdir(tmpDir)){
-                    qDebug()<<"[EE] - Can't create temp directory at: "<<tmpDir;
+                    qDebug()<<"[EE] - Cannot create temp directory at: "<<tmpDir;
                 }
             }
 
             args << "-o" << tmpDir;
             args << fileName;
 
-            Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Exporting icon from binary file.<br>This can take a while..."), tr("Exporting icon"), FALSE);
+            Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), FALSE);
 
             if (exportProcess.exec()==QDialog::Accepted){
             //icotool -x -o ./regedit.png --width=32 --height=32 ./regedit.exe_14_100_0.ico
                 args.clear();
                 args << "-x";
 
+                QDir ico_dir(tmpDir);
                 // Updating file index
-                list = tmp.entryInfoList();
+                list = ico_dir.entryInfoList();
 
                 //Creating file list for converting
                 for (int i = 0; i < list.size(); ++i) {
                     QFileInfo fileInfo = list.at(i);
+                    qDebug() << fileInfo.fileName();
                     if (fileInfo.fileName().right(3)=="ico")
                         args << fileInfo.filePath();
                 }
@@ -488,10 +488,10 @@ void IconSettings::cmdGetIcon_Click(){
 
                 //Converting ico files to png
 
-                //Look here, this function checks is some icons found, or not. 5 -- is default number of arguments,
+                //Look here, this function checks if some icons found, or not. 5 -- is default number of arguments,
                 //if more -- then we have some ico file to convert
                 if (args.size()>=4){
-                    Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Convering icon from binary file.<br>This can take a while..."), tr("Converting icon"), FALSE);
+                    Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), FALSE);
                     if (exportProcess.exec()==QDialog::Accepted){
                         IconsView iconsView(tmpDir);
                         if (iconsView.exec()==QDialog::Accepted){
@@ -522,11 +522,11 @@ void IconSettings::cmdGetIcon_Click(){
             for (int i = 0; i < list.size(); ++i) {
                 QFileInfo fileInfo = list.at(i);
                     if (!QFile::remove(fileInfo.filePath()))
-                        qDebug()<<"[EE] - Can't delete files at: "<<fileInfo.filePath();
+                        qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
             }
 
             if (!tmp.rmdir(tmpDir))
-                qDebug()<<"[EE] - Can't delete tmp dir: "<<tmpDir;
+                qDebug()<<"[EE] - Cannot delete tmp dir: "<<tmpDir;
         }
 
         if (!fileName.isEmpty())
@@ -549,7 +549,7 @@ void IconSettings::cmdOk_Click(){
   }
 
   if (!QDir(txtWorkDir->text()).exists()){
-      QMessageBox::warning(this, tr("Error"), tr("Selected working directory not exists."));
+      QMessageBox::warning(this, tr("Error"), tr("Selected working directory does not exist."));
       return;
   }
 
@@ -561,12 +561,12 @@ void IconSettings::cmdOk_Click(){
   if (icon_name!=txtName->text()){
       if (this->dir_name.isEmpty()){
           if (db_icon.isExistsByName(this->prefix_name, txtName->text())){
-              QMessageBox::warning(this, tr("Error"), tr("Sorry, but icon named %1 already exists.").arg(txtName->text()));
+              QMessageBox::warning(this, tr("Error"), tr("Sorry, an icon named %1 already exists.").arg(txtName->text()));
               return;
           }
       } else {
           if (db_icon.isExistsByName(this->prefix_name, this->dir_name, txtName->text())){
-              QMessageBox::warning(this, tr("Error"), tr("Sorry, but icon named %1 already exists.").arg(txtName->text()));
+              QMessageBox::warning(this, tr("Error"), tr("Sorry, an icon named %1 already exists.").arg(txtName->text()));
               return;
           }
       }
@@ -579,11 +579,11 @@ void IconSettings::cmdOk_Click(){
             override.append("n;");
         if (twDlls->item(i-1, 1)->text()==tr("Disabled"))
             override.append("'';");
-        if (twDlls->item(i-1, 1)->text()==tr("Buildin"))
+        if (twDlls->item(i-1, 1)->text()==tr("Built-in"))
             override.append("b;");
-        if (twDlls->item(i-1, 1)->text()==tr("Native, Buildin"))
+        if (twDlls->item(i-1, 1)->text()==tr("Native, Built-in"))
             override.append("n,b;");
-        if (twDlls->item(i-1, 1)->text()==tr("Buildin, Native"))
+        if (twDlls->item(i-1, 1)->text()==tr("Built-in, Native"))
             override.append("b,n;");
     }
 
@@ -600,11 +600,21 @@ void IconSettings::cmdOk_Click(){
         desktopSize="";
 
     switch (this->icon_name.isEmpty()){
-        case TRUE:
-            db_icon.addIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text());
+        case true:
+            db_icon.addIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text(), txtPreRun->text(), txtPostRun->text());
+#ifndef _OS_DARWIN_
+            if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+                CoreLib->createDesktopFile(this->prefix_name, this->dir_name, txtName->text(), true);
+#endif
         break;
-        case FALSE:
-            db_icon.updateIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), icon_name, override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text());
+        case false:
+            db_icon.updateIcon(txtCmdArgs->text(), txtProgramPath->text(), iconPath, txtDesc->text(), this->prefix_name, this->dir_name, txtName->text(), icon_name, override, txtWinedebug->text(), useconsole, txtDisplay->text(), txtWorkDir->text(), desktopSize, spinNice->value(), txtEnvLang->text(), txtPreRun->text(), txtPostRun->text());
+#ifndef _OS_DARWIN_
+            if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                CoreLib->deleteDesktopFile(this->prefix_name, this->dir_name, this->icon_name);
+                CoreLib->createDesktopFile(this->prefix_name, this->dir_name, txtName->text(), true);
+            }
+#endif
         break;
     }
 
@@ -613,7 +623,6 @@ void IconSettings::cmdOk_Click(){
     return;
 }
 
-
 void IconSettings::cmdHelp_Click(){
     QString rawurl;
     switch (twbGeneral->currentIndex()){
@@ -626,6 +635,9 @@ void IconSettings::cmdHelp_Click(){
     case 2:
         rawurl = "08-icon-dialog.html#advanced";
     break;
+    case 3:
+        rawurl = "08-icon-dialog.html#scripts";
+    break;
     default:
         rawurl = "08-icon-dialog.html";
     break;
@@ -634,3 +646,50 @@ void IconSettings::cmdHelp_Click(){
     CoreLib->openHelpUrl(rawurl);
 }
 
+void IconSettings::cmdGetPreRun_Click(){
+    QString fileName;
+    QString searchPath = QDir::homePath();
+    searchPath.append("/.config/q4wine/scripts");
+    QFileDialog dialog(this);
+    dialog.setFilter(QDir::Dirs | QDir::Files | QDir::Hidden );
+    dialog.setWindowTitle(tr("Open Exe file"));
+    dialog.setDirectory(searchPath);
+    dialog.setFileMode(QFileDialog::ExistingFile);
+    dialog.setNameFilter(tr("Shell script (*.sh)"));
+
+#if QT_VERSION >= 0x040500
+    if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
+        dialog.setOptions(QFileDialog::DontUseNativeDialog);
+    }
+#endif
+
+    if (dialog.exec())
+       fileName = dialog.selectedFiles().first();
+
+    txtPreRun->setText(fileName);
+    return;
+}
+
+void IconSettings::cmdGetPostRun_Click(){
+    QString fileName;
+    QString searchPath = QDir::homePath();
+    searchPath.append("/.config/q4wine/scripts");
+    QFileDialog dialog(this);
+    dialog.setFilter(QDir::Dirs | QDir::Files | QDir::Hidden );
+    dialog.setWindowTitle(tr("Open Exe file"));
+    dialog.setDirectory(searchPath);
+    dialog.setFileMode(QFileDialog::ExistingFile);
+    dialog.setNameFilter(tr("Shell script (*.sh)"));
+
+#if QT_VERSION >= 0x040500
+    if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0){
+        dialog.setOptions(QFileDialog::DontUseNativeDialog);
+    }
+#endif
+
+    if (dialog.exec())
+       fileName = dialog.selectedFiles().first();
+
+    txtPostRun->setText(fileName);
+    return;
+}
