@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                           *
+ *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey               *
  *   brezerk@gmail.com                                                     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
@@ -20,10 +20,9 @@
 #include "mainwindow.h"
 
 MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt::WFlags f) : QMainWindow(parent, f){
-
      // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -31,7 +30,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
         libq4wine.load();
     }
 
-    // Getting corelib calss pointer
+    // Getting corelib class pointer
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
     CoreLib.reset((corelib *)CoreLibClassPointer(true));
 
@@ -60,48 +59,22 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
 
     setWindowTitle(tr("%1 :. Qt4 GUI for Wine v%2").arg(APP_NAME) .arg(APP_VERS));
 
-    cbPrefixes.reset(new QComboBox(tabPrefixSeup));
-    cbPrefixes->setMinimumWidth(180);
-    std::auto_ptr<QToolBar> toolbar (new QToolBar(tabPrefixSeup));
-    std::auto_ptr<QLabel> label (new QLabel(QString(" %1 ").arg(tr("Current prefix:"))));
-
-    toolbar->addWidget(label.release());
-    toolbar->addWidget(cbPrefixes.get());
-
-    std::auto_ptr<QAction> action (new QAction(CoreLib->loadIcon("data/configure.png"), tr("Manage prefixes"), this));
-    action->setStatusTip(tr("Manage prefixes"));
-    connect(action.get(), SIGNAL(triggered()), this, SLOT(prefixManage_Click()));
-
-    toolbar->addAction(action.release());
-    toolbar->addSeparator();
-
-    action.reset(new QAction(CoreLib->loadIcon("data/regedit.png"), tr("Run Winetricks plugin"), this));
-    action->setStatusTip(tr("Run Winetricks plugin"));
-    connect(action.get(), SIGNAL(triggered()), this, SLOT(prefixRunWinetricks_Click()));
-
-    toolbar->addAction(action.release());
-
     std::auto_ptr<QVBoxLayout> vlayout (new QVBoxLayout);
-    vlayout->addWidget(toolbar.release());
-    vlayout->addWidget(frame);
-    vlayout->setMargin(0);
-    vlayout->setSpacing(0);
-    tabPrefixSeup->setLayout(vlayout.release());
 
-    frame->setAutoFillBackground(true);
+    std::auto_ptr<PrefixConfigWidget> configWidget (new PrefixConfigWidget(tabPrefixSeup));
+    connect(configWidget.get(), SIGNAL(updateDatabaseConnections()), this, SLOT(updateDtabaseConnectedItems()));
+    connect(configWidget.get(), SIGNAL(setTabIndex (int)), tbwGeneral, SLOT(setCurrentIndex (int)));
+    connect(this, SIGNAL(updateDatabaseConnections()), configWidget.get(), SLOT(getPrefixes()));
 
     std::auto_ptr<LoggingWidget> logWidget (new LoggingWidget(tabLogging));
     connect (this, SIGNAL(reloadLogData()), logWidget.get(), SLOT(getLogRecords()));
 
-     if (CoreLib->getSetting("logging", "enable", false, 0).toInt()==1){
-         logWidget->getLogRecords();
-     } else {
-         tabLogging->setEnabled(false);
-     }
+    logWidget->getLogRecords();
 
-     logLayout->addWidget(logWidget.release());
+    logLayout->addWidget(logWidget.release());
 
     std::auto_ptr<IconListWidget> lstIcons (new IconListWidget(tabPrograms));
+    connect(this, SIGNAL(runProgramRequest(QString)), lstIcons.get(), SLOT(runProgramRequest(QString)));
     connect(lstIcons.get(), SIGNAL(iconItemClick(QString, QString, QString, QString, QString)), this, SLOT(updateIconDesc(QString, QString, QString, QString, QString)));
     connect(lstIcons.get(), SIGNAL(changeStatusText(QString)), this, SLOT(changeStatusText(QString)));
     connect(lstIcons.get(), SIGNAL(appRunned(bool)), this, SLOT(setMeVisible(bool)));
@@ -117,8 +90,8 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     connect(twPrograms.get(), SIGNAL(setSearchFocus()), this, SLOT(setSearchFocus()));
     connect(twPrograms.get(), SIGNAL(changeStatusText(QString)), this, SLOT(changeStatusText(QString)));
     connect(this, SIGNAL(setDefaultFocus(QString, QString)), twPrograms.get(), SLOT(setDefaultFocus(QString, QString)));
-    connect(cbPrefixes.get(), SIGNAL(currentIndexChanged(QString)), twPrograms.get(), SLOT(setDefaultFocus(QString)));
-    connect(twPrograms.get(), SIGNAL(prefixIndexChanged(QString)), this, SLOT(setcbPrefixesIndex(QString)));
+    connect(configWidget.get(), SIGNAL(prefixIndexChanged(QString)), twPrograms.get(), SLOT(setDefaultFocus(QString)));
+    connect(twPrograms.get(), SIGNAL(prefixIndexChanged(QString)), configWidget.get(), SLOT(setPrefix(QString)));
     connect(twPrograms.get(), SIGNAL(setTabIndex (int)), tbwGeneral, SLOT(setCurrentIndex (int)));
 
     connect(twPrograms.get(), SIGNAL(pasteAction()), lstIcons.get(), SLOT(iconPaste_Click()));
@@ -133,8 +106,8 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     std::auto_ptr<PrefixControlWidget> prefixWidget (new PrefixControlWidget(tabPrefix));
     connect(prefixWidget.get(), SIGNAL(updateDatabaseConnections()), twPrograms.get(), SLOT(getPrefixes()));
     connect(prefixWidget.get(), SIGNAL(updateDatabaseConnections()), this, SLOT(updateDtabaseConnectedItems()));
-    connect(cbPrefixes.get(), SIGNAL(currentIndexChanged(QString)), prefixWidget.get(), SLOT(setDefaultFocus(QString)));
-    connect(prefixWidget.get(), SIGNAL(prefixIndexChanged(QString)), this, SLOT(setcbPrefixesIndex(QString)));
+    connect(configWidget.get(), SIGNAL(prefixIndexChanged(QString)), prefixWidget.get(), SLOT(setDefaultFocus(QString)));
+    connect(prefixWidget.get(), SIGNAL(prefixIndexChanged(QString)), configWidget.get(), SLOT(setPrefix(QString)));
     connect(prefixWidget.get(), SIGNAL(setTabIndex (int)), tbwGeneral, SLOT(setCurrentIndex (int)));
     connect(twPrograms.get(), SIGNAL(updateDatabaseConnections()), prefixWidget.get(), SLOT(updateDtabaseItems()));
 
@@ -177,6 +150,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     vlayout->setContentsMargins(3,0,3,3);
     tabPrograms->setLayout(vlayout.release());
     tabPrefixLayout->addWidget(prefixWidget.release());
+    setupLayout->addWidget(configWidget.release());
 
     // Updating database connected items
     updateDtabaseConnectedItems();
@@ -186,8 +160,8 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     this->getSettings();
 
     connect(tbwGeneral, SIGNAL(currentChanged(int)), this, SLOT(tbwGeneral_CurrentTabChange(int)));
-    connect(cmdCreateFake, SIGNAL(clicked()), this, SLOT(cmdCreateFake_Click()));
-    connect(cmdUpdateFake, SIGNAL(clicked()), this, SLOT(cmdUpdateFake_Click()));
+    //connect(cmdCreateFake, SIGNAL(clicked()), this, SLOT(cmdCreateFake_Click()));
+    //connect(cmdUpdateFake, SIGNAL(clicked()), this, SLOT(cmdUpdateFake_Click()));
 
     //Main menu actions connection to slots
     connect(mainRun, SIGNAL(triggered()), this, SLOT(mainRun_Click()));
@@ -248,44 +222,17 @@ void MainWindow::clearTmp(){
     QString fileName = QDir::homePath();
     fileName.append("/.config/");
     fileName.append(APP_SHORT_NAME);
-    fileName.append("/tmp/");
+    fileName.append("/tmp");
 
-    QDir dir(fileName);
-    dir.setFilter(QDir::Files | QDir::Hidden | QDir::NoSymLinks);
-
-    QFileInfoList list = dir.entryInfoList();
-    for (int i = 0; i < list.size(); ++i) {
-        QFile(list.at(i).absoluteFilePath()).remove();
-    }
-
-    fileName = QDir::homePath();
-    fileName.append("/.config/");
-    fileName.append(APP_SHORT_NAME);
-    fileName.append("/tmp/cache/");
-
-    dir.setPath(fileName);
-
-    list = dir.entryInfoList();
-    for (int i = 0; i < list.size(); ++i) {
-        QFile(list.at(i).absoluteFilePath()).remove();
-    }
-    return;
-}
-
-void MainWindow::prefixRunWinetricks_Click() {
-    if (CoreLib->getSetting("console", "bin").toString().isEmpty()){
-        QMessageBox::warning(this, tr("Error"), tr("<p>You do not set default console binary.</p><p>Set it into q4wine option dialog.</p>"));
+    if (not CoreLib->removeDirectory(fileName)){
+        qWarning()<<"[WW] Can't clear "<<fileName;
         return;
     }
 
-    if (CoreLib->getSetting("DialogFlags", "winetricksPlugin", false, 0).toInt()==0){
-        InfoDialog info(0);
-        if (info.exec()==QDialog::Rejected)
-            return;
+    if (!CoreLib->checkDirs(QStringList() << "tmp" << "tmp/cache")){
+        return;
     }
 
-    winetricks tricks(cbPrefixes->currentText());
-    tricks.exec();
     return;
 }
 
@@ -341,9 +288,9 @@ void MainWindow::getSettings(){
      */
     QVariant val;
 
-    val = CoreLib->getSetting("MainWindow", "size", false, QSize(400, 450));
+    val = CoreLib->getSetting("MainWindow", "size", false, QSize(600, 500));
     this->resize(val.toSize());
-    val = CoreLib->getSetting("MainWindow", "pos", false, QPoint(200, 200));
+    val = CoreLib->getSetting("MainWindow", "pos", false, QPoint(100, 100));
     this->move(val.toPoint());
 
     QList<int> a;
@@ -367,6 +314,14 @@ void MainWindow::getSettings(){
 
     emit(setDefaultFocus(CoreLib->getSetting("LastPrefix", "prefix", false).toString(), CoreLib->getSetting("LastPrefix", "dir", false).toString()));
 
+#ifndef _OS_DARWIN_
+    //make root
+    if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+        sys_menu.create_dir_info();
+        sys_menu.generateSystemMenu();
+    }
+#endif
+
     return;
 }
 
@@ -375,18 +330,7 @@ void MainWindow::changeStatusText(QString text){
 }
 
 void MainWindow::updateDtabaseConnectedItems(){
-    QString curPrefix =  cbPrefixes->currentText();
-
-    cbPrefixes->clear();
-    QStringList list = db_prefix.getPrefixList();
-    cbPrefixes->addItems (list);
-
     emit(updateDatabaseConnections());
-
-    if (!curPrefix.isEmpty()){
-        cbPrefixes->setCurrentIndex(cbPrefixes->findText(curPrefix));
-    }
-
     return;
 }
 
@@ -397,35 +341,34 @@ void MainWindow::searchRequest(QString search){
 }
 #endif
 
-void MainWindow::prefixManage_Click(){
-    tbwGeneral->setCurrentIndex (3);
-    return;
-}
-
 bool MainWindow::createSocket(){
     serverSoket.reset(new QLocalServer(this));
 #ifdef DEBUG
-    qDebug()<<"[ii] Creating q4wine socket";
+    qDebug()<<"[ii] Creating Q4Wine socket";
 #endif
 
-    char *user = getenv("USER");
-
-    QString soketFile = QString("/tmp/q4wine-%1.sock").arg(user);
+    QString soketFile = QString("/tmp/q4wine-%1.sock").arg(getuid());
+#ifdef DEBUG
+    qDebug()<<"[ii] Socket file name:"<<soketFile;
+#endif
 
     if (QFile(soketFile).exists()){
         QMessageBox msgBox;
         msgBox.setText(tr("Socket file \"%1\" already exists!").arg(soketFile));
-        msgBox.setInformativeText(tr("It seems another instance of q4wine is running, or q4wine was shutdown incorrectly. Do you want to remove it?"));
+        msgBox.setInformativeText(tr("It seems that another instance of Q4Wine is running, or Q4Wine was shutdown incorrectly. Do you wish to remove the socket file?"));
         msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
         msgBox.setDefaultButton(QMessageBox::Cancel);
-        if (msgBox.exec() == QMessageBox::Ok)
+        if (msgBox.exec() == QMessageBox::Ok){
             QFile(soketFile).remove();
+        } else {
+            exit(255);
+        }
     }
 
     if (!serverSoket->listen(soketFile)){
         QTextStream QErr(stderr);
-        QErr<<"[EE] Can't create q4wine socket: "<<serverSoket->errorString()<<endl;
-        return false;
+        QErr<<"[EE] Cannot create Q4Wine socket: "<<serverSoket->errorString()<<endl;
+        exit(255);
     }
 
     connect (serverSoket.get(), SIGNAL(newConnection()), this, SLOT(newConnection()));
@@ -468,7 +411,7 @@ void MainWindow::newConnection (){
 
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
                             if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notifycation"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         }
 
                         emit(reloadLogData());
@@ -482,7 +425,7 @@ void MainWindow::newConnection (){
 
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
                         if ((this->isHidden() || this->isMinimized()) && (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notifycation"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" started fine for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         }
 
                         emit(reloadLogData());
@@ -495,7 +438,7 @@ void MainWindow::newConnection (){
                         this->changeStatusText(tr("Application: \"%1\" finished for prefix: \"%2\". Exit code is: \"%3\".").arg(list.at(1)).arg(list.at(2)).arg(list.at(3)));
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
                         if ((this->isHidden() || this->isMinimized()) && trayIcon->isVisible()){
-                            this->showNotifycation(tr("helper notifycation"), tr("Application: \"%1\" finished for prefix: \"%2\". Exit code is: \"%3\".").arg(list.at(1)).arg(list.at(2)).arg(list.at(3)));
+                            this->showNotifycation(tr("helper notification"), tr("Application: \"%1\" finished for prefix: \"%2\". Exit code is: \"%3\".").arg(list.at(1)).arg(list.at(2)).arg(list.at(3)));
                         }
 
                         emit(reloadLogData());
@@ -504,20 +447,20 @@ void MainWindow::newConnection (){
                     }
                 } else if (list.at(0)=="error"){
                     if (list.count()==3){
-                        this->changeStatusText(tr("Can't start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                        this->changeStatusText(tr("Cannot start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
                         if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notifycation"), tr("Can't start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            this->showNotifycation(tr("helper notification"), tr("Cannot start application: \"%1\" for prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         }
                     } else {
                         this->showSocketError(message);
                     }
                 } else if (list.at(0)=="console_error"){
                     if (list.count()==3){
-                        this->changeStatusText(tr("Can't start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                        this->changeStatusText(tr("Cannot start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
                         if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
                         if ((this->isHidden() || this->isMinimized()) and (trayIcon->isVisible())){
-                            this->showNotifycation(tr("helper notifycation"), tr("Can't start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
+                            this->showNotifycation(tr("helper notification"), tr("Cannot start console for application: \"%1\" in prefix: \"%2\".").arg(list.at(1)).arg(list.at(2)));
 
                         }
                     } else {
@@ -615,63 +558,6 @@ void MainWindow::tbwGeneral_CurrentTabChange(int tabIndex){
     return;
 }
 
-void MainWindow::cmdCreateFake_Click(){
-
-    QString prefixPath = db_prefix.getPath(cbPrefixes->currentText());
-    QString sysregPath;
-    sysregPath.append(prefixPath);
-    sysregPath.append("/system.reg");
-
-    QFile sysreg_file (sysregPath);
-
-    if (sysreg_file.exists()){
-        if (QMessageBox::warning(this, tr("Warning"), tr("A fake drive already exists within <b>%1</b>.<br><br>Do you wish to remove <b>all</b> files from this prefix?").arg(prefixPath), QMessageBox::Yes, QMessageBox::No)==QMessageBox::Yes){
-
-            QStringList args;
-            args << "-rf";
-            args << prefixPath;
-            Process exportProcess(args, "/bin/rm", QDir::homePath(), tr("Removing old fake drive.<br>This may take awhile..."), tr("Removing old fake drive"));
-
-            if (exportProcess.exec()!=QDialog::Accepted){
-                return;
-            }
-        } else {
-            return;
-        }
-    }
-
-    FakeDriveSettings settings(cbPrefixes->currentText());
-    settings.loadDefaultPrefixSettings();
-
-    if (settings.exec()==QDialog::Accepted){
-        updateDtabaseConnectedItems();
-    }
-
-    return;
-}
-
-void MainWindow::cmdUpdateFake_Click(){
-    QString prefixPath = db_prefix.getPath(cbPrefixes->currentText());
-
-    QString sysregPath;
-    sysregPath.append(prefixPath);
-    sysregPath.append("/system.reg");
-
-    QFile sysreg_file (sysregPath);
-
-    if (!sysreg_file.exists()){
-        QMessageBox::warning(this, tr("Error"), tr("Sorry, no fake drive configuration found.<br>Create fake drive configuration before update it!"));
-    } else {
-        FakeDriveSettings settings(cbPrefixes->currentText());
-        settings.loadPrefixSettings();
-
-        if (settings.exec()==QDialog::Accepted){
-            updateDtabaseConnectedItems();
-        }
-    }
-    return;
-}
-
 void MainWindow::mainExit_Click(){
     /*
      * main Menu Exit
@@ -797,12 +683,7 @@ void MainWindow::mainRun_Click(){
     /*
      * main Menu shows Run dialog
      */
-    if (cbPrefixes->currentText().isEmpty())
-        return;
-
-    Run run;
-    run.prepare(cbPrefixes->currentText());
-    run.exec();
+    emit (runProgramRequest(QString()));
     return;
 }
 
@@ -835,13 +716,6 @@ void MainWindow::mainOptions_Click(){
             QApplication::setQuitOnLastWindowClosed(true);
             trayIcon->hide();
         }
-
-        if (CoreLib->getSetting("logging", "enable", false, 1).toInt()==1){
-            emit(reloadLogData());
-            tabLogging->setEnabled(true);
-        } else {
-            tabLogging->setEnabled(false);
-        }
     }
 
     return;
@@ -862,7 +736,7 @@ void MainWindow::mainInstall_Click(){
      * main Menu shows install Wizard dialog
      */
 
-    QMessageBox::warning(this, tr("WIP"), tr("Sorry, no install wizard yet. It'l  implemented at v0.110."));
+    QMessageBox::warning(this, tr("WIP"), tr("Sorry, the install wizard has not been implemented yet. It will be available in a future version."));
 
     return;
 }
@@ -922,9 +796,9 @@ void MainWindow::mainExportIcons_Click(){
         if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
                 options = QFileDialog::DontUseNativeDialog;
 
-    fileName = QFileDialog::getOpenFileName(this, tr("Open image file"), QDir::homePath(), tr("Win32 Executable and Shared libraies (*.exe *.dll);;Win32 Executable (*.exe);;Win32 Shared libraies (*.dll)"), 0, options );
+    fileName = QFileDialog::getOpenFileName(this, tr("Open image file"), QDir::homePath(), tr("Win32 Executable and Shared libraries (*.exe *.dll);;Win32 Executable (*.exe);;Win32 Shared libraries (*.dll)"), 0, options );
 #else
-    fileName = QFileDialog::getOpenFileName(this, tr("Open image file"), QDir::homePath(), tr("Win32 Executable and Shared libraies (*.exe *.dll);;Win32 Executable (*.exe);;Win32 Shared libraies (*.dll)") );
+    fileName = QFileDialog::getOpenFileName(this, tr("Open image file"), QDir::homePath(), tr("Win32 Executable and Shared libraries (*.exe *.dll);;Win32 Executable (*.exe);;Win32 Shared libraries (*.dll)") );
 #endif
 
     if(fileName.isEmpty())
@@ -951,12 +825,12 @@ void MainWindow::mainExportIcons_Click(){
         for (int i = 0; i < list.size(); ++i) {
             QFileInfo fileInfo = list.at(i);
             if (!tmp.remove(fileInfo.filePath()))
-                qDebug()<<"[EE] - Can't delete files at: "<<fileInfo.filePath();
+                qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
         }
 
     } else {
         if (!tmp.mkdir(tmpDir)){
-            qDebug()<<"[EE] - Can't create temp directory at: "<<tmpDir;
+            qDebug()<<"[EE] - Cannot create temp directory at: "<<tmpDir;
         }
     }
 
@@ -964,7 +838,7 @@ void MainWindow::mainExportIcons_Click(){
     args << "-o" << tmpDir;
     args << fileName;
 
-    Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Exporting icon from binary file.<br>This can take a while..."), tr("Exporting icon"), false);
+    Process exportProcess(args, CoreLib->getSetting("icotool", "wrestool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
 
     if (exportProcess.exec()==QDialog::Accepted){
         //icotool -x -o ./regedit.png --width=32 --height=32 ./regedit.exe_14_100_0.ico
@@ -986,11 +860,11 @@ void MainWindow::mainExportIcons_Click(){
         }
 
 
-        //Look here, this function checks is some icons found, or not. 5 -- is default number of arguments,
+        //Look here, this function checks if some icons found, or not. 5 -- is default number of arguments,
         //if more -- then we have some ico file to convert
         if (args.size()>=4){
 
-            Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Convering icon from binary file.<br>This can take a while..."), tr("Converting icon"), false);
+            Process exportProcess(args, CoreLib->getSetting("icotool", "icotool").toString(), QDir::homePath(), tr("Extracting icon from binary file.<br>This can take a while..."), tr("Extracting icon"), false);
 
             if (exportProcess.exec()==QDialog::Accepted){
                 IconsView iconsView(tmpDir);
@@ -1010,11 +884,11 @@ void MainWindow::mainExportIcons_Click(){
     for (int i = 0; i < list.size(); ++i) {
         QFileInfo fileInfo = list.at(i);
         if (!QFile::remove(fileInfo.filePath()))
-            qDebug()<<"[EE] - Can't delete files at: "<<fileInfo.filePath();
+            qDebug()<<"[EE] - Cannot delete files at: "<<fileInfo.filePath();
     }
 
     if (!tmp.rmdir(tmpDir))
-        qDebug()<<"[EE] - Can't delete tmp dir: "<<tmpDir;
+        qDebug()<<"[EE] - Cannot delete tmp dir: "<<tmpDir;
 
     return;
 }
@@ -1057,7 +931,7 @@ void MainWindow::mainImportWineIcons_Click(){
 
 
         prefixPath.append("/dosdevices/c:/users/");
-        prefixPath.append(getenv("USER"));
+        prefixPath.append(QString::fromUtf8(getenv("USER")));
 
         QFileInfo fileinfo(QString("%1/%2").arg(prefixPath).arg(CoreLib->decodeRegString(list.at(0).split("\\\\").last())));
         if (fileinfo.isSymLink()){
@@ -1070,6 +944,11 @@ void MainWindow::mainImportWineIcons_Click(){
         progress.exec();
     }
 
+#ifndef _OS_DARWIN_
+    if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+        sys_menu.generateSystemMenu();
+#endif
+
     updateDtabaseConnectedItems();
     return;
 }
@@ -1110,34 +989,18 @@ void MainWindow::messageReceived(const QString message){
     } else  {
         if (!QFile(message).exists()){
             if (!trayIcon->isVisible()){
-                statusBar()->showMessage(tr("Binary \"%1\" do not exists.").arg(message));
+                statusBar()->showMessage(tr("Binary \"%1\" does not exist.").arg(message));
             } else {
                 if (CoreLib->getSetting("app", "showNotifications", false, 1).toInt()==1)
-                    this->showNotifycation(tr("Can't run binary"), tr("Binary \"%1\" do not exists.").arg(message));
+                    this->showNotifycation(tr("Cannot run binary"), tr("Binary \"%1\" does not exist.").arg(message));
             }
         } else {
-            if (cbPrefixes->currentText().isEmpty())
-                return;
-
-            QString wrkDir;
-            wrkDir = message.left(message.length() - QStringList(message.split("/")).last().length());
-
-            Run run;
-            run.prepare(cbPrefixes->currentText(), wrkDir, "", "", "", "", "", "", 0, message);
-            run.exec();
+            emit (runProgramRequest(message));
         }
     }
-
     return;
 }
 
-void MainWindow::setcbPrefixesIndex(const QString text) const{
-    cbPrefixes->setCurrentIndex(cbPrefixes->findText(text));
-    return;
-}
-
-
-
 /*
 void MainWindow::getWineMenuIcons(void){
     QStringList prefixList;
