@@ -19,12 +19,14 @@
 
 /*!
  * \defgroup q4wine-gui Q4Wine GUI
- * \brief q4wine-gui pakage provide general GUI functions for q4wine.
+ * \brief q4wine-gui package provides general GUI functions for Q4Wine.
  */
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <unistd.h>
+
 #include <src/q4wine-gui/ui_MainWindow.h>
 
 //Qt includes
@@ -41,6 +43,9 @@
 #include "prefix.h"
 #include "dir.h"
 #include "icon.h"
+#ifndef _OS_DARWIN_
+#include "sysmenu.h"
+#endif
 
 //Widgets
 #include "loggingwidget.h"
@@ -50,6 +55,7 @@
 #include "prefixtreetoolbar.h"
 #include "wineprocesswidget.h"
 #include "prefixcontrolwidget.h"
+#include "prefixconfigwidget.h"
 
 #ifdef WITH_WINEAPPDB
 #include "appdbwidget.h"
@@ -91,7 +97,6 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 
     public slots:
             void messageReceived(const QString message);
-            void setcbPrefixesIndex(const QString text) const;
             void updateDtabaseConnectedItems(void);
             void setSearchFocus(void);
             void setMeVisible(bool visible);
@@ -110,13 +115,6 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
         /*
          * Command buttons slots
          */
-
-        void cmdCreateFake_Click(void);
-        void cmdUpdateFake_Click(void);
-
-        void prefixManage_Click(void);
-        void prefixRunWinetricks_Click (void);
-
         void updateIconDesc(QString program, QString args, QString desc, QString console, QString desktop);
 
         //Main menu slots
@@ -151,7 +149,6 @@ private:
 #ifdef WITH_WINEAPPDB
         std::auto_ptr<AppDBWidget> appdbWidget;
 #endif
-        std::auto_ptr<QComboBox> cbPrefixes;
         std::auto_ptr<QLocalServer> serverSoket;
 
         //! This is need for libq4wine-core.so import;
@@ -164,7 +161,9 @@ private:
         Prefix db_prefix;
         Dir db_dir;
         Icon db_icon;
-
+#ifndef _OS_DARWIN_
+        system_menu sys_menu;
+#endif
         // Tray icon
         std::auto_ptr<QSystemTrayIcon> trayIcon;
 
@@ -193,6 +192,7 @@ private:
         void startProcTimer(void);
 
         void reloadLogData(void);
+        void runProgramRequest(QString);
 
     protected:
         // Events
