@@ -29,7 +29,7 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::WFlags
 
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -97,6 +97,7 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::WFlags
 
     txtPrefixName->setText(prefix_name);
     txtPrefixPath->setText(result.value("path"));
+    txtRunString->setText(result.value("run_string"));
 
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
@@ -107,6 +108,7 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::WFlags
     cmdGetMountPoint->installEventFilter(this);
 
     cmdOk->setFocus(Qt::ActiveWindowFocusReason);
+
     return;
 }
 
@@ -120,7 +122,11 @@ PrefixSettings::PrefixSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent,
     this->addNew=true;
 
     // Loading libq4wine-core.so
-    libq4wine.setFileName("libq4wine-core");
+#ifdef RELEASE
+    libq4wine.setFileName(_CORELIB_PATH_);
+#else
+    libq4wine.setFileName("../q4wine-lib/libq4wine-core");
+#endif
 
     if (!libq4wine.load()){
         libq4wine.load();
@@ -139,13 +145,15 @@ PrefixSettings::PrefixSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent,
     cmdGetWineLibs->installEventFilter(this);
     cmdGetMountPoint->installEventFilter(this);
 
-    //comboArchList->setEnabled(true);
+    txtRunString->setText(RUN_STRING_TEMPLATE);
 
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
     connect(cmdHelp, SIGNAL(clicked()), this, SLOT(cmdHelp_Click()));
 
-    cmdCancel->setFocus(Qt::ActiveWindowFocusReason);
+    connect(txtPrefixName, SIGNAL(textChanged(QString)), this, SLOT(setDefPath(QString)));
+
+    txtPrefixName->setFocus(Qt::ActiveWindowFocusReason);
     return;
 }
 
@@ -172,8 +180,8 @@ void PrefixSettings::cmdCancel_Click(){
 
 void PrefixSettings::cmdOk_Click(){
     if (txtPrefixName->text().isEmpty()){
-         QMessageBox::warning(this, tr("Error"), tr("Please, enter prefix name"));
-          return;
+        QMessageBox::warning(this, tr("Error"), tr("Enter a prefix name"));
+        return;
     }
 
     if (prefix_name!=txtPrefixName->text()){
@@ -190,13 +198,40 @@ void PrefixSettings::cmdOk_Click(){
     }
 
     if (this->addNew){
-        if (!db_prefix.addPrefix(txtPrefixName->text(),  txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), comboArchList->currentText(), this->comboWinDrive->currentText()))
+
+        QDir directory(path);
+        if (directory.exists()){
+            if(QMessageBox::warning(this, tr("Warning"), tr("Directory \"%1\" already exists. Do you wish to use it anyway?").arg(path), QMessageBox::Yes, QMessageBox::No)==QMessageBox::No)
+                return;
+        } else {
+            // In case of non default arch, wine will fail to run wine programs from existent
+            // empty prefix directory.
+            // So we will try to create parent folders, but not prefix dir itself.
+            if (!directory.mkpath("./../")) {
+                QMessageBox::critical(this, tr("Error"), tr("The directory \"%1\" could not be created.").arg(path), QMessageBox::Ok);
+                return;
+            }
+        }
+
+        if (!db_prefix.addPrefix(txtPrefixName->text(),  txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), comboArchList->currentText(), this->comboWinDrive->currentText(), this->txtRunString->text()))
             reject();
 
         CoreLib->createPrefixDBStructure(txtPrefixName->text());
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+            sys_menu.generateSystemMenu(txtPrefixName->text());
+#endif
     } else {
-        if (!db_prefix.updatePrefix(txtPrefixName->text(), txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), this->prefix_name, comboArchList->currentText(), this->comboWinDrive->currentText()))
+        if (!db_prefix.updatePrefix(txtPrefixName->text(), txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), this->prefix_name, comboArchList->currentText(), this->comboWinDrive->currentText(), this->txtRunString->text()))
             reject();
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+            if (this->prefix_name != txtPrefixName->text()){
+                sys_menu.remove_dir_info(this->prefix_name);
+                sys_menu.generateSystemMenu(txtPrefixName->text());
+            }
+        }
+#endif
     }
 
     accept();
@@ -219,9 +254,9 @@ bool PrefixSettings::eventFilter(QObject *obj, QEvent *event){
             if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
                 options = QFileDialog::DontUseNativeDialog;
 
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(),   "All files (*.*)", 0, options);
+            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(), "All files (*)", 0, options);
 #else
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(),   "All files (*.*)");
+            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(), "All files (*)");
 #endif
         } else {
 #if QT_VERSION >= 0x040500
@@ -279,6 +314,9 @@ void PrefixSettings::cmdHelp_Click(){
     case 1:
         rawurl = "10-prefix-settings.html#winepath";
     break;
+    case 2:
+        rawurl = "10-prefix-settings.html#advanced";
+    break;
     }
 
     CoreLib->openHelpUrl(rawurl);
@@ -292,3 +330,14 @@ void PrefixSettings::getWineCdromLetter(){
         }
     }
 }
+
+void PrefixSettings::setDefPath(QString prefix_name){
+    QString path = CoreLib->getSetting("advanced", "prefixDefaultPath").toString();
+    if (this->txtPrefixPath->text().isEmpty() or this->txtPrefixPath->text().startsWith(path)){
+        if (!path.endsWith("/"))
+            path.append("/");
+        path.append(prefix_name);
+
+        this->txtPrefixPath->setText(path);
+    }
+}
