@@ -60,7 +60,7 @@ void Process::slotError(QProcess::ProcessError err){
 
 		QTextCodec *codec = QTextCodec::codecForName(lang.toAscii());
 		if (!codec){
-			stdErr<<"[ee] Can't setup codec for \""<<lang<<"\""<<endl;
+			stdErr<<"[ee] Cannot setup codec for \""<<lang<<"\""<<endl;
 			stdErr<<"[ee] Aborting current operation!"<<endl;
 			reject();
 			return;
@@ -69,7 +69,7 @@ void Process::slotError(QProcess::ProcessError err){
 		QString string = codec->toUnicode(myProcess->readAllStandardError());
 
 		if (!string.isEmpty()){
-			QMessageBox::warning(this, tr("Error"), tr("It seems procces fail.<br><br>Error log:<br>%1").arg(string));
+			QMessageBox::warning(this, tr("Error"), tr("It seems that the process failed.<br><br>Error log:<br>%1").arg(string));
 		} else {
 			switch (err){
 			case 0:
@@ -133,7 +133,7 @@ void Process::slotFinished(int, QProcess::ExitStatus exitc){
 		// Read STDERR with locale support
 		QTextCodec *codec = QTextCodec::codecForName(lang.toAscii());
 		if (!codec){
-			stdErr<<"[ee] Can't setup codec for \""<<lang<<"\""<<endl;
+			stdErr<<"[ee] Cannot setup codec for \""<<lang<<"\""<<endl;
 			stdErr<<"[ee] Aborting current operation!"<<endl;
 			reject();
 			return;
@@ -150,12 +150,12 @@ void Process::slotFinished(int, QProcess::ExitStatus exitc){
 		if (!string.isEmpty()){
 			if ((exitc == 0) && (myProcess->exitCode() == 0)){
 				if (showErr){
-					QMessageBox::warning(this, tr("Output"), tr("It seems the process exited normally.<br><br>STDERR log:<br>%1").arg(string));
+					QMessageBox::warning(this, tr("Output"), tr("It seems that the process exited normally.<br><br>STDERR log:<br>%1").arg(string));
 				}
 				accept();
                 return;
 			} else {
-				QMessageBox::warning(this, tr("Output"), tr("It seems the process crashed.<br><br>STDERR log:<br>%1").arg(string));
+				QMessageBox::warning(this, tr("Output"), tr("It seems that the process crashed.<br><br>STDERR log:<br>%1").arg(string));
 				reject();
                 return;
 			}
