@@ -25,7 +25,7 @@ Run::Run(QWidget * parent, Qt::WFlags f) : QDialog(parent, f)
     setupUi(this);
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -106,11 +106,11 @@ void Run::prepare(QString prefix_name, QString wrkdir, QString override, QString
             if (list2.at(1)=="n")
                 overrideorder = tr("Native");
             if (list2.at(1)=="b")
-                overrideorder = tr("Buildin");
+                overrideorder = tr("Built-in");
             if (list2.at(1)=="n,b")
-                overrideorder = tr("Native, Buildin");
+                overrideorder = tr("Native, Built-in");
             if (list2.at(1)=="b,n")
-                overrideorder = tr("Buildin, Native");
+                overrideorder = tr("Built-in, Native");
 
             newItem.reset(new QTableWidgetItem(overrideorder));
             newItem->setFlags( Qt::ItemIsEnabled | Qt::ItemIsSelectable );
@@ -160,7 +160,7 @@ void Run::cmdOk_Click(){
     }
 
     if (!QDir(txtWorkDir->text()).exists()){
-        QMessageBox::warning(this, tr("Error"), tr("Selected working directory not exists."));
+        QMessageBox::warning(this, tr("Error"), tr("Selected working directory does not exist."));
         return;
     }
 
@@ -171,11 +171,11 @@ void Run::cmdOk_Click(){
             override.append("n;");
         if (twDlls->item(i-1, 1)->text()==tr("Disabled"))
             override.append("'';");
-        if (twDlls->item(i-1, 1)->text()==tr("Buildin"))
+        if (twDlls->item(i-1, 1)->text()==tr("Built-in"))
             override.append("b;");
-        if (twDlls->item(i-1, 1)->text()==tr("Native, Buildin"))
+        if (twDlls->item(i-1, 1)->text()==tr("Native, Built-in"))
             override.append("n,b;");
-        if (twDlls->item(i-1, 1)->text()==tr("Buildin, Native"))
+        if (twDlls->item(i-1, 1)->text()==tr("Built-in, Native"))
             override.append("b,n;");
     }
 
@@ -244,11 +244,11 @@ void Run::getPrefixes(){
         comboPrefixes->addItem(list.at(i));
         if (list.at(i)==this->prefix_name){
             comboPrefixes->setCurrentIndex ( comboPrefixes->findText(list.at(i)) );
-            prefix_dir = db_prefix.getPath(list.at(i));
-            getWineDlls(db_prefix.getLibsPath(list.at(i)));
+            QHash<QString,QString> pref = db_prefix.getByName(prefix_name);
+            prefix_dir = pref.value("path");
+            getWineDlls(pref.value("libs"));
         }
     }
-
     return;
 }
 
