@@ -24,7 +24,7 @@ AppDBWidget::AppDBWidget(QWidget *parent) : QWidget(parent)
 
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -47,6 +47,7 @@ AppDBWidget::AppDBWidget(QWidget *parent) : QWidget(parent)
     this->createActions();
 
     std::auto_ptr<QToolBar> toolbar (new QToolBar());
+    toolbar->setIconSize(QSize(24, 24));
     toolbar->addAction(appdbOpen.get());
     toolbar->addAction(appdbAppPage.get());
     toolbar->addSeparator();
@@ -264,22 +265,22 @@ void AppDBWidget::httpcore_pageDownloaded(void){
 void AppDBWidget::showXmlError(int id){
     switch (id){
     case 1:
-        this->appdbHeader->addLabel(tr("Error: can't read data from %1.").arg(APP_WEBSITTE));
+        this->appdbHeader->addLabel(tr("Error: cannot read data from %1.").arg(APP_WEBSITE));
         break;
     case 2:
-        this->appdbHeader->addLabel(tr("Error: wrong or broken xml data. Try again later."));
+        this->appdbHeader->addLabel(tr("Error: wrong or broken XML data. Try again later."));
         break;
     case 3:
-        this->appdbHeader->addLabel(tr("Error: wrong or broken appdb xml version. Application needs to be updated?"));
+        this->appdbHeader->addLabel(tr("Error: wrong or broken AppDB XML version. This might be caused by an outdated application version."));
         break;
     case 4:
-        this->appdbHeader->addLabel(tr("Error: xml parse error."));
+        this->appdbHeader->addLabel(tr("Error: XML parse error."));
         break;
     case 6:
         this->appdbHeader->addLabel(tr("Error: unexpected error."));
         break;
     case 404:
-        this->appdbHeader->addLabel(tr("Search: No matches found"));
+        this->appdbHeader->addLabel(tr("Search: No matches found."));
         break;
     }
     this->setCursor(QCursor(Qt::ArrowCursor));
@@ -305,12 +306,12 @@ void AppDBWidget::createActions(void){
     appdbClearSearch->setStatusTip(tr("Clear search field"));
     connect(appdbClearSearch.get(), SIGNAL(triggered()), this, SLOT(appdbClearSearch_Click()));
 
-    appdbSearch.reset(new QAction(CoreLib->loadIcon("data/find.png"), tr("Search in appdb"),this));
-    appdbSearch->setStatusTip(tr("Search in wine appdb"));
+    appdbSearch.reset(new QAction(CoreLib->loadIcon("data/find.png"), tr("Search in AppDB"),this));
+    appdbSearch->setStatusTip(tr("Search in Wine AppDB"));
     connect(appdbSearch.get(), SIGNAL(triggered()), this, SLOT(appdbSearch_Click()));
 
-    appdbCat.reset(new QAction(CoreLib->loadIcon("data/list.png"), tr("Appdb categoryes list"),this));
-    appdbCat->setStatusTip(tr("View wine appdb categoryes list"));
+    appdbCat.reset(new QAction(CoreLib->loadIcon("data/list.png"), tr("AppDB categories list"),this));
+    appdbCat->setStatusTip(tr("View Wine AppDB categories list"));
     connect(appdbCat.get(), SIGNAL(triggered()), this, SLOT(appdbCat_Click()));
 
     return;
