@@ -23,7 +23,7 @@ IconListWidget::IconListWidget(QWidget *parent) : QListWidget (parent)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -36,24 +36,20 @@ IconListWidget::IconListWidget(QWidget *parent) : QListWidget (parent)
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
     CoreLib.reset((corelib *)CoreLibClassPointer(true));
 
-    setAcceptDrops(true);
     setResizeMode(QListView::Adjust);
     setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
     setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
-    setMovement(QListView::Static);
-    setDragDropMode(QAbstractItemView::NoDragDrop);
     setSelectionMode(QAbstractItemView::ContiguousSelection);
 
-    this->setDragEnabled(false);
+    this->view_mode = CoreLib->getSetting("IconWidget", "ViewMode", false, D_VIEW_MODE_ICON).toInt();
+    setDisplayType(this->view_mode);
 
-    if (CoreLib->getSetting("IconWidget", "ViewMode", false, "IconMode").toString()=="ListMode"){
-        setDisplayType(false);
-    } else {
-        setDisplayType(true);
-    }
+    this->sort_order = CoreLib->getSetting("IconWidget", "IconSort", false, D_SORT_TYPE_BY_DATE_ASC).toInt();
 
     connect(this, SIGNAL(itemClicked (QListWidgetItem *)), this, SLOT(itemClicked (QListWidgetItem *)));
     connect(this, SIGNAL(itemDoubleClicked (QListWidgetItem *)), this, SLOT(itemDoubleClicked (QListWidgetItem *)));
+    connect(this, SIGNAL(currentItemChanged (QListWidgetItem *, QListWidgetItem *)), this, SLOT(itemChanged (QListWidgetItem *, QListWidgetItem *)));
+
 
     this->dirName="";
     this->prefixName="";
@@ -66,11 +62,8 @@ IconListWidget::IconListWidget(QWidget *parent) : QListWidget (parent)
 IconListWidget::~IconListWidget(){
     QSettings settings(APP_SHORT_NAME, "default");
     settings.beginGroup("IconWidget");
-    if (viewMode()==QListView::IconMode){
-        settings.setValue("ViewMode", "IconMode");
-    } else {
-        settings.setValue("ViewMode", "ListMode");
-    }
+    settings.setValue("ViewMode", this->view_mode);
+    settings.setValue("IconSort", this->sort_order);
     settings.setValue("IconSize",  iconSize().height());
     settings.endGroup();
 }
@@ -88,7 +81,7 @@ void IconListWidget::showContents(QString filterString){
     this->clear();
     emit(iconItemClick("","","","",""));
 
-    QStringList iconsList=db_icon.getIconsList(this->prefixName, this->dirName, filterString);
+    QStringList iconsList=db_icon.getIconsList(this->prefixName, this->dirName, filterString, this->sort_order);
 
     for (int i = 0; i < iconsList.size(); ++i) {
         std::auto_ptr<QListWidgetItem> iconItem (new QListWidgetItem(this, 0));
@@ -96,7 +89,7 @@ void IconListWidget::showContents(QString filterString){
         iconItem->setToolTip(iconsList.at(i));
 
 
-        //Seting icon. If no icon or icon file not exists -- setting default
+        //Seting icon. If no icon or icon file does not exist -- setting default
         QString icon_path = db_icon.getPixmapIcon(this->prefixName, this->dirName, iconsList.at(i));
         if (icon_path.isEmpty()){
             iconItem->setIcon(CoreLib->loadIcon("data/exec_wine.png"));
@@ -108,23 +101,13 @@ void IconListWidget::showContents(QString filterString){
                 if (QFile::exists (icon_path)){
                     iconItem->setIcon(QIcon(icon_path));
                 } else {
-                    if (iconsList.at(i)=="console"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/wineconsole.png"));
-                    } else if (iconsList.at(i)=="regedit"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/regedit.png"));
-                    } else if (iconsList.at(i)=="wordpad"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/notepad.png"));
-                    } else if (iconsList.at(i)=="winecfg"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/winecfg.png"));
-                    } else if (iconsList.at(i)=="uninstaller"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/uninstaller.png"));
-                    } else if (iconsList.at(i)=="eject"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/eject.png"));
-                    } else if (iconsList.at(i)=="explorer"){
-                        iconItem->setIcon(CoreLib->loadIcon("data/explorer.png"));
-                    } else {
-                        iconItem->setIcon(CoreLib->loadIcon("data/exec_wine.png"));
-                    }
+                    QIcon ico = CoreLib->loadIcon(QString("data/%1.png").arg(iconsList.at(i)));
+                    // Do not work due to: https://bugreports.qt-project.org/browse/QTBUG-999
+                    //if (ico.isNull()){
+                    if (ico.availableSizes().isEmpty())
+                        ico = CoreLib->loadIcon("data/exec_wine.png");
+
+                    iconItem->setIcon(ico);
                 }
             }
         }
@@ -144,9 +127,9 @@ void IconListWidget::setFilterString(QString filterString){
 
 void IconListWidget::changeView(int action){
     if (action==0){
-        setDisplayType(false);
+        setDisplayType(D_VIEW_MODE_LIST);
     } else if (action==1){
-        setDisplayType(true);
+        setDisplayType(D_VIEW_MODE_ICON);
     } else if (action==2){
         if (iconSize().height()<64){
             int nSize = iconSize().height()+8;
@@ -167,16 +150,28 @@ void IconListWidget::changeView(int action){
                 setGridSize(QSize(nSize, nSize));
             }
         }
+    } else if (action==4){
+        if (this->sort_order == D_SORT_TYPE_BY_NAME_ASC){
+            this->sort_order = D_SORT_TYPE_BY_NAME_DSC;
+        } else {
+            this->sort_order = D_SORT_TYPE_BY_NAME_ASC;
+        }
+        this->showContents(this->filterString);
+    } else if (action==5){
+        if (this->sort_order == D_SORT_TYPE_BY_DATE_ASC){
+            this->sort_order = D_SORT_TYPE_BY_DATE_DSC;
+        } else {
+            this->sort_order = D_SORT_TYPE_BY_DATE_ASC;
+        }
+        this->showContents(this->filterString);
     }
-
     return;
 }
 
-void IconListWidget::setDisplayType(bool icon){
-
+void IconListWidget::setDisplayType(int type){
     int nSize = CoreLib->getSetting("IconWidget", "IconSize", false, 32).toInt();
-
-    if (icon){
+    this->view_mode = type;
+    if (type == D_VIEW_MODE_ICON) {
         setViewMode(QListView::IconMode);
         setGridSize(QSize(nSize+54, nSize+54));
         setIconSize(QSize(nSize, nSize));
@@ -193,6 +188,7 @@ void IconListWidget::setDisplayType(bool icon){
 }
 
 void IconListWidget::startDrag(){
+#ifndef _OS_DARWIN_
     if (this->prefixName.isEmpty())
         return;
 
@@ -215,6 +211,7 @@ void IconListWidget::startDrag(){
         drag->start(Qt::MoveAction);
         drag.release();
     }
+#endif
 }
 
 void IconListWidget::startDrop(QList<QUrl> files){
@@ -231,7 +228,7 @@ void IconListWidget::startDrop(QList<QUrl> files){
 
             while (db_icon.isExistsByName(this->prefixName, this->dirName, fileName)){
                 bool ok=false;
-                fileName = QInputDialog::getText(this, tr("Sorry. It seems icon already exists."), tr("Sorry. It seems icon already exists.<br>Please choose another name, or cancel operation."), QLineEdit::Normal, fileName , &ok);
+                fileName = QInputDialog::getText(this, tr("Sorry. It seems that the icon already exists."), tr("Sorry. It seems that icon already exists.<br>Please choose another name or cancel the operation."), QLineEdit::Normal, fileName , &ok);
 
                 if (!ok){
                     this->showContents("");
@@ -247,6 +244,11 @@ void IconListWidget::startDrop(QList<QUrl> files){
             } else {
                 db_icon.addIcon("", file, "", "", this->prefixName, this->dirName, fileName, "", "", "", "", file.left(file.length() - file.split("/").last().length()), "", 0);
             }
+#ifndef _OS_DARWIN_
+            if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+                CoreLib->createDesktopFile(this->prefixName, this->dirName, fileName, true);
+#endif
+
         } else if (files.at(i).toLocalFile().contains(".iso", Qt::CaseInsensitive) || files.at(i).toLocalFile().contains(".mdf", Qt::CaseInsensitive) || files.at(i).toLocalFile().contains(".nrg", Qt::CaseInsensitive)){
 
             if (CoreLib->mountImage(files.at(i).toLocalFile(), this->prefixName)){
@@ -258,6 +260,11 @@ void IconListWidget::startDrop(QList<QUrl> files){
             CoreLib->updateRecentImagesList(files.at(i).toLocalFile());
         }
     }
+#ifndef _OS_DARWIN_
+    if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+        sys_menu.writeXMLSystemMenu();
+#endif
+
     this->showContents("");
 }
 
@@ -268,8 +275,9 @@ void IconListWidget::itemClicked (QListWidgetItem *item){
     QHash<QString, QString> result=db_icon.getByName(this->prefixName, this->dirName, item->text());
     emit(iconItemClick(result.value("exec").split('/').last().split('\\').last(), result.value("cmdargs"), result.value("desc"), result.value("useconsole"), result.value("desktop")));
 
-    if (CoreLib->getSetting("advanced", "useSingleClick", false, 0).toInt()==1)
-        itemDoubleClicked (item);
+    if (QApplication::mouseButtons() == Qt::LeftButton)
+        if (CoreLib->getSetting("advanced", "useSingleClick", false, 0).toInt()==1)
+            itemDoubleClicked (item);
 
     return;
 }
@@ -316,6 +324,7 @@ void IconListWidget::mousePressEvent(QMouseEvent *event){
     QListWidget::mousePressEvent(event);
 }
 
+#ifndef _OS_DARWIN_
 void IconListWidget::mouseMoveEvent(QMouseEvent *event){
     if (itemAt(event->pos()) && dragstarted){
         if (event->buttons() & Qt::LeftButton){
@@ -328,9 +337,9 @@ void IconListWidget::mouseMoveEvent(QMouseEvent *event){
             return;
         }
     }
-
     QListWidget::mouseMoveEvent(event);
 }
+#endif
 
 void IconListWidget::dragEnterEvent(QDragEnterEvent *event){
     if (event->mimeData()->hasFormat("text/uri-list"))
@@ -577,19 +586,19 @@ void IconListWidget::contextMenuEvent (QContextMenuEvent * event){
         subMenu.reset(new QMenu(tr("Copy to clipboard"), this));
 
         entry.reset(new QAction(tr("Directory path"), this));
-        entry->setStatusTip(tr("Copy application directory path to system's' clipboard"));
+        entry->setStatusTip(tr("Copy application directory path to system's clipboard"));
         connect(entry.get(), SIGNAL(triggered()), this, SLOT(iconCopyWrkDir_Click()));
         subMenu->addAction(entry.release());
 
         entry.reset(new QAction(tr("Application path"), this));
-        entry->setStatusTip(tr("Copy full application path to system's' clipboard"));
+        entry->setStatusTip(tr("Copy full application path to system's clipboard"));
         connect(entry.get(), SIGNAL(triggered()), this, SLOT(iconCopyProgramPath_Click()));
         subMenu->addAction(entry.release());
 
         subMenu->addSeparator();
 
         entry.reset(new QAction(CoreLib->loadIcon("data/q4wine.png"), tr("q4wine-cli cmd"), this));
-        entry->setStatusTip(tr("Copy q4wine-cli cmd for current application"));
+        entry->setStatusTip(tr("Copy q4wine-cli command for current application"));
         connect(entry.get(), SIGNAL(triggered()), this, SLOT(iconCopyQ4WineCmd_Click()));
         subMenu->addAction(entry.release());
 
@@ -600,7 +609,7 @@ void IconListWidget::contextMenuEvent (QContextMenuEvent * event){
         std::auto_ptr<QMenu> menuRun (new QMenu(tr("Run..."), this));
 
         std::auto_ptr<QAction> entry (new QAction(CoreLib->loadIcon("data/folder.png"), tr("Browse..."), this));
-        entry->setStatusTip(tr("Browse for other image"));
+        entry->setStatusTip(tr("Browse for another image"));
 
         connect(menuRun.get(), SIGNAL(triggered(QAction*)), this, SLOT(menuRun_triggered(QAction*)));
         menuRun->addAction(entry.release());
@@ -734,6 +743,10 @@ void IconListWidget::iconAdd_Click(void){
     IconSettings iconAddWizard(this->prefixName, this->dirName);
     if (iconAddWizard.exec() == QDialog::Accepted){
         this->showContents("");
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+            sys_menu.writeXMLSystemMenu();
+#endif
     }
     return;
 }
@@ -753,13 +766,20 @@ void IconListWidget::iconRename_Click(void){
     QString newName = QInputDialog::getText(this, tr("Enter new icon name"), tr("Icon name:"), QLineEdit::Normal, iconItem->text(), &ok);
     if (ok && !newName.isEmpty()){
         while (db_icon.isExistsByName(this->prefixName, this->dirName, newName)){
-            newName = QInputDialog::getText(this, tr("Sorry. It seems icon already exists."), tr("Sorry. It seems icon already exists.<br>Please choose another name, or cancel operation."), QLineEdit::Normal, newName, &ok);
+            newName = QInputDialog::getText(this, tr("Sorry. It seems that the icon already exists."), tr("Sorry. It seems that the icon already exists.<br>Please choose another name or cancel the operation."), QLineEdit::Normal, newName, &ok);
             if ((!ok) || (newName.isEmpty())){
                 iconItem.release();
                 return;
             }
         }
         db_icon.renameIcon(iconItem->text(), this->prefixName, this->dirName, newName);
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+            CoreLib->deleteDesktopFile(this->prefixName, this->dirName, iconItem->text());
+            CoreLib->createDesktopFile(this->prefixName, this->dirName, newName, true);
+            sys_menu.writeXMLSystemMenu();
+        }
+#endif
     }
     iconItem.release();
     this->showContents(this->filterString);
@@ -778,7 +798,15 @@ void IconListWidget::iconDelete_Click(void){
     if (QMessageBox::warning(this, tr("Delete Icon"), tr("Do you wish to delete all of the selected icons?"),  QMessageBox::Yes, QMessageBox::No	)==QMessageBox::Yes){
         for (int i=0; i<icoList.count(); i++){
             db_icon.delIcon(this->prefixName, this->dirName, icoList.at(i)->text());
+#ifndef _OS_DARWIN_
+            if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+                CoreLib->deleteDesktopFile(this->prefixName, this->dirName, icoList.at(i)->text());
+#endif
         }
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+            sys_menu.writeXMLSystemMenu();
+#endif
         this->showContents(this->filterString);
     }
     return;
@@ -807,7 +835,7 @@ void IconListWidget::iconCut_Click(void){
 
     // If icon cutted -- set icon disabled style
     // FIXME: It pice works fine, but we need to use pixmaps for grayscale, not Qt::ItemIsEnabled flag....
-    // FIXME: It is optional, i don't work on it until release... ;)
+    // FIXME: It is optional, i do not work on it until release... ;)
     //icoList2 = lstIcons->findItems("*", Qt::MatchWrap | Qt::MatchWildcard);
 
     //	for (int i=0; i<icoList2.count(); i++){
@@ -860,18 +888,19 @@ void IconListWidget::iconCopy_Click(void){
 }
 
 void IconListWidget::iconPaste_Click(void){
-    bool fexists=false, ok=false;
+    //bool fexists=false
+    bool ok=false;
     QString newName="";
 
     if (iconBuffer.names.count()>0){
         for (int i=0; i<iconBuffer.names.count(); i++){
             // Checking for not unic names
             newName = iconBuffer.names.at(i);
-            fexists=false;
+            //fexists=false;
             ok=false;
 
             while (db_icon.isExistsByName(this->prefixName, this->dirName, newName)){
-                newName = QInputDialog::getText(this, tr("Sorry. It seems icon already exists."), tr("Sorry. It seems icon already exists.<br>Please choose another name, or cancel operation."), QLineEdit::Normal, iconBuffer.names.at(i) , &ok);
+                newName = QInputDialog::getText(this, tr("Sorry. It seems that the icon already exists."), tr("Sorry. It seems that the icon already exists.<br>Please choose another name or cancel the operation."), QLineEdit::Normal, iconBuffer.names.at(i) , &ok);
                 if (!ok){
                     return;
                 }
@@ -881,13 +910,28 @@ void IconListWidget::iconPaste_Click(void){
             case false:
                 if (!db_icon.copyIcon(iconBuffer.names.at(i), iconBuffer.prefix_name, iconBuffer.dir_name, newName, this->prefixName, this->dirName))
                     return;
+#ifndef _OS_DARWIN_
+                if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+                    CoreLib->createDesktopFile(this->prefixName, this->dirName, newName, true);
+#endif
                 break;
             case true:
                 if (!db_icon.updateIcon(newName, db_prefix.getId(this->prefixName), db_dir.getId(this->dirName, this->prefixName), db_prefix.getId(iconBuffer.prefix_name), db_dir.getId(iconBuffer.dir_name, iconBuffer.prefix_name), iconBuffer.names.at(i)))
                     return;
+#ifndef _OS_DARWIN_
+                if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                    CoreLib->deleteDesktopFile(iconBuffer.prefix_name, iconBuffer.dir_name, iconBuffer.names.at(i));
+                    CoreLib->createDesktopFile(this->prefixName, this->dirName, newName, true);
+                }
+#endif
+                break;
             }
 
         }
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+            sys_menu.writeXMLSystemMenu();
+#endif
     }
 
     if (iconBuffer.move){
@@ -912,6 +956,10 @@ void IconListWidget::iconOption_Click(void){
     IconSettings iconAddWizard(this->prefixName, this->dirName, iconItem->text());
     if (iconAddWizard.exec() == QDialog::Accepted){
         this->showContents(this->filterString);
+#ifndef _OS_DARWIN_
+        if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool())
+            sys_menu.writeXMLSystemMenu();
+#endif
     }
     iconItem.release();
     return;
@@ -990,7 +1038,7 @@ void IconListWidget::iconCopyQ4WineCmd_Click(){
     if (!iconItem.get())
         return;
 
-    QString run_string = QString("%1/bin/q4wine-cli ").arg(APP_PREF);
+    QString run_string = QString("%1/bin/q4wine-cli ").arg(QString::fromUtf8(APP_PREF));
     run_string.append(" -p \"");
     run_string.append(this->prefixName);
     run_string.append("\"");
@@ -1010,7 +1058,23 @@ void IconListWidget::iconCopyQ4WineCmd_Click(){
     iconItem.release();
 
     return;
-};
+}
+
+void IconListWidget::runProgramRequest(QString message){
+    if (this->prefixName.isEmpty())
+        return;
+
+    Run run;
+    if (message.isEmpty()){
+        run.prepare(this->prefixName);
+    } else {
+        QString wrkDir;
+        wrkDir = message.left(message.length() - QStringList(message.split("/")).last().length());
+        run.prepare(this->prefixName, wrkDir, "", "", "", "", "", "", 0, message);
+    }
+    run.exec();
+    return;
+}
 
 void IconListWidget::menuRun_triggered(QAction* action){
     if (action->text().isEmpty())
@@ -1073,8 +1137,7 @@ void IconListWidget::menuMount_triggered(QAction* action){
         QString fileFilter;
 #ifdef _OS_LINUX_
         fileFilter = tr("Disc image files (*.iso *.nrg *.img *.bin *.mdf)");
-#endif
-#ifdef _OS_FREEBSD_
+#else
         fileFilter =  tr("ISO image files (*.iso)");
 #endif
 
@@ -1113,16 +1176,16 @@ void IconListWidget::menuMount_triggered(QAction* action){
     if (ret){
         emit(changeStatusText(tr("%1 successfully mounted.").arg(action->text())));
     } else {
-        emit(changeStatusText(tr("Fail to mount %1.").arg(action->text())));
+        emit(changeStatusText(tr("Failed to mount %1.").arg(action->text())));
     }
     return;
 }
 
 void IconListWidget::menuUmount_Click(void){
     if (CoreLib->umountImage(this->prefixName)){
-        emit(changeStatusText(tr("Drive successfully umounted.")));
+        emit(changeStatusText(tr("Drive successfully unmounted.")));
     } else {
-        emit(changeStatusText(tr("Fail to umount drive.")));
+        emit(changeStatusText(tr("Failed to unmount drive.")));
     }
     return;
 }
@@ -1211,7 +1274,7 @@ void IconListWidget::consoleToPrefixDir_Click(void){
     QString prefix_path = db_prefix.getPath(this->prefixName);
 
     if (prefix_path.isEmpty()){
-        qDebug()<<"[EE] Can't get prefix path";
+        qDebug()<<"[EE] Cannot get prefix path";
     } else {
         CoreLib->openConsole(prefix_path, this->prefixName);
     }
@@ -1245,3 +1308,11 @@ void IconListWidget::consoleToIconDir_Click(void){
     item.release();
     return;
 }
+
+void IconListWidget::itemChanged (QListWidgetItem *item, QListWidgetItem *){
+    if (!item)
+        return;
+
+    itemClicked(item);
+    return;
+}
