@@ -35,6 +35,9 @@
 //Windows
 #include "run.h"
 #include "iconsettings.h"
+#ifndef _OS_DARWIN_
+#include "sysmenu.h"
+#endif
 
 //Qt includes
 #include <QMenu>
@@ -68,28 +71,36 @@ public slots:
       void setFilterString(QString filterString);
       void changeView(int action);
       void iconPaste_Click(void);
+      void runProgramRequest(QString);
 
 private:
       void mousePressEvent(QMouseEvent *event);
+#ifndef _OS_DARWIN_
       void mouseMoveEvent(QMouseEvent *event);
+#endif
       void dragEnterEvent(QDragEnterEvent *event);
       void dragMoveEvent(QDragMoveEvent *event);
       void dropEvent(QDropEvent *event);
       void contextMenuEvent(QContextMenuEvent *event);
       void keyPressEvent (QKeyEvent * event );
 
-      void setDisplayType(bool icon=true);
+      void setDisplayType(int type);
 
       QString prefixName, dirName, prefixMediaDrive, prefixMontPoint, filterString;
       QPoint startPos;
       QStringList cdromDevices;
       bool drag, dragstarted;
+      int sort_order;
+      int view_mode;
 
       // Database classes
       Prefix db_prefix;
       Dir db_dir;
       Icon db_icon;
       Image db_image;
+#ifndef _OS_DARWIN_
+      system_menu sys_menu;
+#endif
 
       // Copy/Paste buffer
       iconCopyBuffer iconBuffer;
@@ -108,6 +119,7 @@ private slots:
 
       void itemClicked (QListWidgetItem *item);
       void itemDoubleClicked (QListWidgetItem *item);
+      void itemChanged (QListWidgetItem *item, QListWidgetItem *);
 
       void iconAdd_Click(void);
       void iconRename_Click(void);
@@ -134,15 +146,15 @@ private slots:
       void winefileOpenMountDir_Click(void);
       void winefileOpenIconDir_Click(void);
 
-          void consoleToPrefixDir_Click(void);
-          void consoleToMountDir_Click(void);
-          void consoleToIconDir_Click(void);
+      void consoleToPrefixDir_Click(void);
+      void consoleToMountDir_Click(void);
+      void consoleToIconDir_Click(void);
 
 signals:
       void iconItemClick(QString, QString, QString, QString, QString);
       void changeStatusText(QString);
       void searchRequest(QString);
-          void appRunned(bool state);
+      void appRunned(bool state);
 };
 
 #endif // ICONLISTWIDGET_H
