@@ -24,7 +24,7 @@ PrefixControlWidget::PrefixControlWidget(QWidget *parent) :
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -40,6 +40,7 @@ PrefixControlWidget::PrefixControlWidget(QWidget *parent) :
     this->createActions();
 
     std::auto_ptr<QToolBar> toolBar (new QToolBar(this));
+    toolBar->setIconSize(QSize(24, 24));
     toolBar->addAction(prefixAdd.get());
     toolBar->addSeparator ();
     toolBar->addAction(prefixImport.get());
@@ -123,8 +124,8 @@ void PrefixControlWidget::createActions(){
     connect(prefixSettings.get(), SIGNAL(triggered()), this, SLOT(prefixSettings_Click()));
     prefixSettings->setEnabled(FALSE);
 
-    prefixSetup.reset(new QAction(CoreLib->loadIcon("data/eject.png"), tr("Setup prefix fake drive"), this));
-    prefixSetup->setStatusTip(tr("Setup prefix fake drive and applications"));
+    prefixSetup.reset(new QAction(CoreLib->loadIcon("data/eject.png"), tr("Set up prefix fake drive"), this));
+    prefixSetup->setStatusTip(tr("Set up prefix fake drive and applications"));
     connect(prefixSetup.get(), SIGNAL(triggered()), this, SLOT(prefixSetup_Click()));
     prefixSetup->setEnabled(FALSE);
 
@@ -219,15 +220,21 @@ void PrefixControlWidget::prefixDelete_Click(){
         return;
 
     if (prefixName=="Default"){
-            QMessageBox::warning(this, tr("Error"), tr("Sorry, you can't delete Default prefix."), QMessageBox::Ok);
+            QMessageBox::warning(this, tr("Error"), tr("Sorry, you cannot delete the Default prefix."), QMessageBox::Ok);
             return;
     }
 
-    if(QMessageBox::warning(this, tr("Warning"),	tr("Do you really wish to delete prefix named \"%1\" and all associated icons?").arg(prefixName), QMessageBox::Ok, QMessageBox::Cancel)==QMessageBox::Ok){
+    if(QMessageBox::warning(this, tr("Warning"), tr("Do you really wish to delete the prefix named \"%1\" and all associated icons?").arg(prefixName), QMessageBox::Ok, QMessageBox::Cancel)==QMessageBox::Ok){
         if (db_icon.delIconsByPrefixName(prefixName))
-            if(db_dir.delDir(prefixName))
+            if(db_dir.delDir(prefixName)){
                 db_prefix.delByName(prefixName);
-
+#ifndef _OS_DARWIN_
+                if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                    sys_menu.remove_dir_info(prefixName);
+                    sys_menu.writeXMLSystemMenu();
+                }
+#endif
+            }
         this->updateTableModel();
         emit(updateDatabaseConnections());
     }
@@ -335,15 +342,25 @@ void PrefixControlWidget::prefixExport_Click(){
     /*
      * Function for exporting preefix to file
      */
+#ifdef DEBUG
+    qDebug()<<"[ii] prefixExport_Click()";
+#endif
     if (!prefixTable->currentIndex().isValid())
         return;
-
+#ifdef DEBUG
+    qDebug()<<"[ii] index is valid";
+#endif
     if(prefixTable->currentIndex().row()<0)
         return;
-
+#ifdef DEBUG
+    qDebug()<<"[ii] row is valid";
+#endif
     QString prefixName = model->index(prefixTable->currentIndex().row(), 0, QModelIndex()).data().toString();
     QString prefixPath = model->index(prefixTable->currentIndex().row(), 2, QModelIndex()).data().toString();
 
+#ifdef DEBUG
+    qDebug()<<"[ii] name: " << prefixName << " Path: " << prefixPath;
+#endif
     if (prefixName.isEmpty())
         return;
 
@@ -361,8 +378,15 @@ void PrefixControlWidget::prefixExport_Click(){
     savepath.append(QDate::currentDate().toString(Qt::ISODate));
     savepath.append(".tbz");
 
+#ifdef DEBUG
+    qDebug()<<"[ii] Path: " << prefixPath << " Save Path: " << savepath;
+#endif
+
     //Request user for valid save path
 #if QT_VERSION >= 0x040500
+#ifdef DEBUG
+    qDebug()<<"[ii] QT_VERSION >= 0x040500";
+#endif
     QFileDialog::Options options;
 
     if (CoreLib->getSetting("advanced", "useNativeFileDialog", false, 1)==0)
@@ -370,6 +394,9 @@ void PrefixControlWidget::prefixExport_Click(){
 
     QString fileName = QFileDialog::getSaveFileName(this, tr("Select file to export"), savepath , tr("Prefix archive images (*.tbz)"), 0, options);
 #else
+#ifdef DEBUG
+    qDebug()<<"[ii] QT_VERSION <= 0x040500";
+#endif
     QString fileName = QFileDialog::getSaveFileName(this, tr("Select file to export"), savepath , tr("Prefix archive images (*.tbz)"));
 #endif
 
