@@ -24,7 +24,7 @@ PrefixTreeWidget::PrefixTreeWidget(QWidget *parent) :
 {
       // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -46,7 +46,8 @@ PrefixTreeWidget::PrefixTreeWidget(QWidget *parent) :
       this->prefixName="";
       this->prefixMontPoint="";
 
-      this->setAcceptDrops(true);
+      //Disabled due to buggy logic
+      this->setAcceptDrops(false);
 
       this->cdromDevices=CoreLib->getCdromDevices();
 }
@@ -106,7 +107,7 @@ void PrefixTreeWidget::dirAdd_Click(void){
 
       if (ok && !dirname.isEmpty()){
            while (db_dir.isExistsByName(this->prefixName, dirname)){
-                dirname = QInputDialog::getText(this, tr("Sorry. It seems directory already exists."), tr("Sorry. It seems directory already exists.<br>Please choose another name, or cancel operation."), QLineEdit::Normal, dirname, &ok);
+                dirname = QInputDialog::getText(this, tr("Sorry. It seems that the directory already exists."), tr("Sorry. It seems that the directory already exists.<br>Please choose another name or cancel the operation."), QLineEdit::Normal, dirname, &ok);
                 if ((!ok) || (dirname.isEmpty())){
                     treeItem.release();
                     return;
@@ -117,6 +118,12 @@ void PrefixTreeWidget::dirAdd_Click(void){
                   treeItem.release();
                   return;
             }
+#ifndef _OS_DARWIN_
+            if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                sys_menu.create_dir_info(this->prefixName, dirname);
+                sys_menu.writeXMLSystemMenu();
+            }
+#endif
 
             if (treeItem->parent()){
                 std::auto_ptr<QTreeWidgetItem> prefixItem (new QTreeWidgetItem(treeItem->parent()));
@@ -156,13 +163,19 @@ void PrefixTreeWidget::dirRename_Click(void){
 
             if (ok && !newName.isEmpty()){
                   while (db_dir.isExistsByName(treeItem->parent()->text(0), newName)){
-                        newName = QInputDialog::getText(this, tr("Sorry. It seems directory already exists."), tr("Sorry. It seems directory already exists.<br>Please choose another name, or cancel operation."), QLineEdit::Normal, newName, &ok);
+                        newName = QInputDialog::getText(this, tr("Sorry. It seems that the directory already exists."), tr("Sorry. It seems that the directory already exists.<br>Please choose another name or cancel the operation."), QLineEdit::Normal, newName, &ok);
                         if ((!ok) || (newName.isEmpty())){
                             treeItem.release();
                             return;
                         }
                   }
                   db_dir.renameDir(treeItem->text(0), treeItem->parent()->text(0), newName);
+#ifndef _OS_DARWIN_
+                  if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                      sys_menu.move_dir_info(treeItem->parent()->text(0), treeItem->text(0), newName);
+                      sys_menu.writeXMLSystemMenu();
+                  }
+#endif
                   treeItem->setText(0, newName);
                   this->itemClicked(treeItem.get(), 0);
             }
@@ -175,21 +188,29 @@ void PrefixTreeWidget::dirRename_Click(void){
 void PrefixTreeWidget::dirDelete_Click(void){
     std::auto_ptr<QTreeWidgetItem> treeItem (this->currentItem());
 
-      if (!treeItem.get())
-            return;
+    if (!treeItem.get())
+        return;
 
-      if (treeItem->parent()){
-            if (QMessageBox::warning(this, tr("Q4Wine"), tr("Do you really wish delete folder named \"%1\" and all associated icons?\n").arg(treeItem->text(0)),
-                                                 QMessageBox::Yes, QMessageBox::No)==QMessageBox::Yes){
+    if (treeItem->parent()){
+        if (QMessageBox::warning(this, tr("Q4Wine"), tr("Do you really wish to delete the folder named \"%1\" and all associated icons?\n").arg(treeItem->text(0)),
+                                 QMessageBox::Yes, QMessageBox::No)==QMessageBox::Yes){
 
             if (db_icon.delIcon(this->prefixName, this->dirName, ""))
-            if (db_dir.delDir(this->prefixName, this->dirName))
-                treeItem->parent()->removeChild(treeItem.get());
-                this->itemClicked(this->currentItem(), 0);
-            }
-      }
-      treeItem.release();
-      return;
+                if (db_dir.delDir(this->prefixName, this->dirName)){
+#ifndef _OS_DARWIN_
+                    if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                        sys_menu.remove_dir_info(this->prefixName, this->dirName);
+                        sys_menu.writeXMLSystemMenu();
+                    }
+#endif
+                    treeItem->parent()->removeChild(treeItem.get());
+                }
+            this->itemClicked(this->currentItem(), 0);
+
+        }
+    }
+    treeItem.release();
+    return;
 }
 
 void PrefixTreeWidget::getPrefixes(){
@@ -201,7 +222,7 @@ void PrefixTreeWidget::getPrefixes(){
             std::auto_ptr<QTreeWidgetItem> prefixItem (new QTreeWidgetItem(this));
             prefixItem->setText(0, QString("%1").arg(list.at(i)));
             prefixItem->setIcon(0, CoreLib->loadIcon("data/wine.png"));
-            if (CoreLib->getSetting("Interface", "expandPrefixTree", false, 1).toInt()==1){
+            if (CoreLib->getSetting("TreeWidget", "State", false, D_TREE_EXPAND).toInt()==D_TREE_EXPAND){
                 prefixItem->setExpanded (TRUE);
             } else {
                 prefixItem->setExpanded (FALSE);
@@ -302,7 +323,7 @@ void PrefixTreeWidget::contextMenuEvent (QContextMenuEvent * event){
             std::auto_ptr<QMenu> menuRun (new QMenu(tr("Run..."), this));
 
             std::auto_ptr<QAction> entry (new QAction(CoreLib->loadIcon("data/folder.png"), tr("Browse ..."), this));
-            entry->setStatusTip(tr("Browse for other image"));
+            entry->setStatusTip(tr("Browse for another image"));
 
             connect(menuRun.get(), SIGNAL(triggered(QAction*)), this, SLOT(menuRun_triggered(QAction*)));
             menuRun->addAction(entry.release());
@@ -407,7 +428,7 @@ void PrefixTreeWidget::contextMenuEvent (QContextMenuEvent * event){
             menu->addAction(entry.release());
 
             entry.reset(new QAction(CoreLib->loadIcon("data/drive_menu.png"), tr("Configure fake drive settings"), this));
-            entry->setStatusTip(tr("Setup prefix fake drive and applications"));
+            entry->setStatusTip(tr("Set up prefix fake drive and applications"));
             connect(entry.get(), SIGNAL(triggered()), this, SLOT(menuSetupPrefix_Click()));
             menu->addAction(entry.release());
 
@@ -498,15 +519,21 @@ void PrefixTreeWidget::moveDesktopFile(QUrl url, QString prefixName, QString dir
     QString newName = icon;
 
     while (db_icon.isExistsByName(prefixName, dirName, newName)){
-          newName = QInputDialog::getText(this, tr("Sorry. It seems icon already exists."), tr("Sorry. It seems icon already exists.<br>Please choose another name, or cancel operation."), QLineEdit::Normal, icon , &ok);
+          newName = QInputDialog::getText(this, tr("Sorry. It seems that the icon already exists."), tr("Sorry. It seems that the icon already exists.<br>Please choose another name or cancel the operation."), QLineEdit::Normal, icon , &ok);
           if (!ok){
                 return;
           }
     }
-
     if (!db_icon.updateIcon(newName, db_prefix.getId(prefixName), db_dir.getId(dirName, prefixName), db_prefix.getId(prefix), db_dir.getId(dir, prefix), icon))
         return;
 
+#ifndef _OS_DARWIN_
+    if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+        CoreLib->deleteDesktopFile(prefix, dir, icon);
+        CoreLib->createDesktopFile(prefixName, dirName, newName, true);
+        sys_menu.writeXMLSystemMenu();
+    }
+#endif
 }
 
 QStringList PrefixTreeWidget::mimeTypes () const
@@ -627,16 +654,16 @@ void PrefixTreeWidget::menuMount_triggered(QAction* action){
       if (ret){
             emit(changeStatusText(tr("%1 successfully mounted.").arg(action->text())));
       } else {
-            emit(changeStatusText(tr("Fail to mount %1.").arg(action->text())));
+            emit(changeStatusText(tr("Failed to mount %1.").arg(action->text())));
       }
       return;
 }
 
 void PrefixTreeWidget::menuUmount_Click(void){
       if (CoreLib->umountImage(this->prefixName)){
-            emit(changeStatusText(tr("Drive successfully umounted.")));
+            emit(changeStatusText(tr("Drive successfully unmounted.")));
       } else {
-            emit(changeStatusText(tr("Fail to umount drive.")));
+            emit(changeStatusText(tr("Failed to unmount drive.")));
       }
       return;
 }
@@ -683,14 +710,21 @@ void PrefixTreeWidget::menuSetupPrefix_Click(void){
 
 void PrefixTreeWidget::menuDeletePrefix_Click(void){
     if (this->prefixName=="Default"){
-        QMessageBox::warning(this, tr("Error"), tr("Sorry, you can't delete Default prefix."), QMessageBox::Ok);
+        QMessageBox::warning(this, tr("Error"), tr("Sorry, you cannot delete the Default prefix."), QMessageBox::Ok);
         return;
     }
 
-    if(QMessageBox::warning(this, tr("Warning"), tr("Do you really wish to delete prefix named \"%1\" and all associated icons?").arg(prefixName), QMessageBox::Ok, QMessageBox::Cancel)==QMessageBox::Ok){
+    if(QMessageBox::warning(this, tr("Warning"), tr("Do you really wish to delete the prefix named \"%1\" and all associated icons?").arg(prefixName), QMessageBox::Ok, QMessageBox::Cancel)==QMessageBox::Ok){
         if (db_icon.delIconsByPrefixName(this->prefixName))
-            if(db_dir.delDir(this->prefixName))
+            if(db_dir.delDir(this->prefixName)){
                 db_prefix.delByName(this->prefixName);
+#ifndef _OS_DARWIN_
+                if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
+                    sys_menu.remove_dir_info(this->prefixName);
+                    sys_menu.writeXMLSystemMenu();
+                }
+#endif
+            }
 
         emit(updateDatabaseConnections());
     }
@@ -735,7 +769,7 @@ void PrefixTreeWidget::consoleToPrefixDir_Click(void){
     QString prefix_path = db_prefix.getPath(this->prefixName);
 
     if (prefix_path.isEmpty()){
-        qDebug()<<"[EE] Can't get prefix path";
+        qDebug()<<"[EE] Cannot get prefix path";
     } else {
         CoreLib->openConsole(prefix_path, this->prefixName);
     }
@@ -752,26 +786,26 @@ void PrefixTreeWidget::consoleToMountDir_Click(void){
 }
 
 void PrefixTreeWidget::setDefaultFocus(QString prefixName, QString dirName){
-    if (prefixName.isEmpty())
-        prefixName="Default";
-
-    if (prefixName==this->prefixName)
-        return;
-
     if (prefixName.isEmpty()){
+        prefixName="Default";
         if (this->topLevelItemCount()>0){
             this->setCurrentItem(this->topLevelItem(0));
             this->itemClicked(this->topLevelItem(0), 0);
             return;
         }
     } else {
+        //skip update
+        if (prefixName == this->prefixName)
+            return;
+
         for(int i=0; i < this->topLevelItemCount(); i++)
         {
             std::auto_ptr<QTreeWidgetItem> item(this->topLevelItem(i));
             if (item->text(0)==prefixName){
                 if (dirName.isEmpty()){
+                    this->setFocus();
                     this->setCurrentItem(item.get());
-                    this->topLevelItem(i)->setExpanded(TRUE);
+                    this->topLevelItem(i)->setExpanded(true);
                     this->itemClicked(item.get(), 0);
                     item.release();
                     break;
