@@ -38,6 +38,10 @@
 #include "prefixsettings.h"
 #include "fakedrivesettings.h"
 
+#ifndef _OS_DARWIN_
+#include "sysmenu.h"
+#endif
+
 //Qt includes
 #include <QTreeWidgetItem>
 #include <QMenu>
@@ -82,6 +86,9 @@ private:
       Prefix db_prefix;
       Dir db_dir;
       Icon db_icon;
+#ifndef _OS_DARWIN_
+      system_menu sys_menu;
+#endif
 
 private slots:
       void itemClicked (QTreeWidgetItem *item, int);
