@@ -23,7 +23,7 @@ WineProcessWidget::WineProcessWidget(QWidget *parent) : QWidget(parent)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
@@ -39,6 +39,7 @@ WineProcessWidget::WineProcessWidget(QWidget *parent) : QWidget(parent)
     this->createActions();
 
     std::auto_ptr<QToolBar> toolBar (new QToolBar(this));
+    toolBar->setIconSize(QSize(24, 24));
     toolBar->addAction(procKillSelected.get());
     toolBar->addAction(procKillWine.get());
     toolBar->addSeparator();
@@ -79,7 +80,7 @@ WineProcessWidget::WineProcessWidget(QWidget *parent) : QWidget(parent)
     this->setLayout(layout.release());
 
     timer.reset(new QTimer());
-    timer->start(1000);
+    //timer->start(1000);
 
     // Connecting signals and slots
     connect(timer.get(), SIGNAL(timeout()), this, SLOT(getWineProcesssInfo()));
@@ -93,7 +94,7 @@ void WineProcessWidget::stopTimer(void){
 
 void WineProcessWidget::startTimer(void){
     this->getWineProcesssInfo();
-    timer->start();
+    timer->start(1000);
     return;
 }
 
@@ -108,7 +109,7 @@ void WineProcessWidget::createActions(){
     procKillWine->setEnabled(false);
     connect(procKillWine.get(), SIGNAL(triggered()), this, SLOT(procKillWine_Click()));
 
-    procRefresh.reset(new QAction(CoreLib->loadIcon("data/reload.png"), tr("Refresh list"),this));
+    procRefresh.reset(new QAction(CoreLib->loadIcon("data/reload.png"), tr("Refresh List"),this));
     procRefresh->setStatusTip(tr("Refresh process list"));
     connect(procRefresh.get(), SIGNAL(triggered()), this, SLOT(getWineProcesssInfo()));
 
@@ -129,6 +130,9 @@ void WineProcessWidget::createActions(){
 }
 
 void WineProcessWidget::getWineProcesssInfo(void){
+#ifdef DEBUG
+    qDebug()<<"[ii] Get Wine process list";
+#endif
     QList<QStringList> proclist = CoreLib->getWineProcessList();
 
     if (proclist.count()<=0){
@@ -197,7 +201,7 @@ void WineProcessWidget::itemClicked(const QModelIndex &){
 }
 
 void WineProcessWidget::procKillSelected_Click(void){
-    if (QMessageBox::warning(this, tr("Warning"), tr("This action will send a KILL(-9) signal to selected processes<br><br>It is HIGH risk to damage wine normal state.<br><br>Do you really want to proceed?"), QMessageBox::Yes, QMessageBox::No)==QMessageBox::No)
+    if (QMessageBox::warning(this, tr("Warning"), tr("This action will send a KILL(-9) signal to selected processes<br><br>It is HIGH risk to damage wine normal state.<br><br>Do you really wish to proceed?"), QMessageBox::Yes, QMessageBox::No)==QMessageBox::No)
         return;
 
     QItemSelectionModel *selectionModel = procTable->selectionModel();
@@ -218,12 +222,12 @@ void WineProcessWidget::procKillSelected_Click(void){
         QString cmd = QString("kill -9 %1").arg(procList.at(i));
 
         if (system(cmd.toAscii().data())==-1){
-            QMessageBox::warning(this, tr("Error"), tr("Can't run: %1").arg(cmd.toAscii().data()), QMessageBox::Ok);
+            QMessageBox::warning(this, tr("Error"), tr("Cannot run: %1").arg(cmd.toAscii().data()), QMessageBox::Ok);
 #ifdef DEBUG
             qDebug()<<"[EE] Fail to run: "<<cmd;
 #endif
         } else {
-            emit(changeStatusText(tr("It seems process %1 killed successfully.").arg(procList.at(i))));
+            emit(changeStatusText(tr("It seems that the process %1 has been killed successfully.").arg(procList.at(i))));
 #ifdef DEBUG
             qDebug()<<"[ii] Run OK: "<<cmd;
 #endif
@@ -234,7 +238,7 @@ void WineProcessWidget::procKillSelected_Click(void){
 }
 
 void WineProcessWidget::procKillWine_Click(void){
-    if (QMessageBox::warning(this, tr("Warning"), tr("This action will send a KILL(-9) signal to all wine processes for selected prefixes<br><br>Do you really want to proceed?"), QMessageBox::Yes, QMessageBox::No)==QMessageBox::No)
+    if (QMessageBox::warning(this, tr("Warning"), tr("This action will send a KILL(-9) signal to all wine processes of the selected prefixes<br><br>Do you really wish to proceed?"), QMessageBox::Yes, QMessageBox::No)==QMessageBox::No)
         return;
 
     QItemSelectionModel *selectionModel = procTable->selectionModel();
@@ -283,7 +287,7 @@ void WineProcessWidget::procRenice_Click(void){
 
     for (int i=0; i<procList.count(); i++){
         if (CoreLib->reniceProcess(procList.at(i), newNice)){
-            emit(changeStatusText(tr("It seems process %1 renice to %2 end successfully.").arg(procList.at(i)).arg(newNice)));
+            emit(changeStatusText(tr("It seems that the process %1 has been reniced to %2 successfully.").arg(procList.at(i)).arg(newNice)));
         }
     }
 
