@@ -39,7 +39,9 @@
 #include "src/core/database/prefix.h"
 #include "src/core/database/icon.h"
 #include "src/core/database/dir.h"
-
+#ifndef _OS_DARWIN_
+#include "sysmenu.h"
+#endif
 
 #include "q4wine-lib.h"
 
