@@ -23,9 +23,9 @@ WineObject::WineObject(QObject *parent) : QObject(parent)
 {
     // Loading libq4wine-core.so
 #ifdef RELEASE
-    libq4wine.setFileName("libq4wine-core");
+    libq4wine.setFileName(_CORELIB_PATH_);
 #else
-    libq4wine.setFileName(QString("%1/q4wine-lib/libq4wine-core").arg(APP_BUILD));
+    libq4wine.setFileName(QString("%1/q4wine-lib/libq4wine-core").arg(QString::fromUtf8(APP_BUILD)));
 #endif
 
     if (!libq4wine.load()){
@@ -39,8 +39,7 @@ WineObject::WineObject(QObject *parent) : QObject(parent)
     this->programNice = 0;
     this->prefixId = 0;
     this->useConsole=false;
-
-    this->user = getenv("USER");
+    this->logEnabled = CoreLib->getSetting("logging", "enable", false, 1).toBool();
 
     return;
 }
@@ -56,6 +55,7 @@ void WineObject::setPrefix(QString prefix){
     this->prefixPath=CoreLib->getStrictEscapeString(prefix_info.value("path"));
     this->prefixServer=CoreLib->getStrictEscapeString(prefix_info.value("server"));
     this->prefixArch=prefix_info.value("arch");
+    this->prefixRunString=prefix_info.value("run_string");
     return;
 }
 
@@ -112,6 +112,18 @@ void WineObject::setUseConsole(int console){
     return;
 }
 
+void WineObject::setPreRun(QString path){
+    //FIXME add check
+    this->prerun_script = path;
+    return;
+}
+
+void WineObject::setPostRun(QString path){
+    //FIXME add check
+    this->postrun_script = path;
+    return;
+}
+
 QString WineObject::createEnvString(){
     QString env;
     if (this->prefixName.isEmpty())
@@ -124,8 +136,13 @@ QString WineObject::createEnvString(){
     if (!this->prefixArch.isEmpty())
         env.append(QString(" WINEARCH='%1' ").arg(this->prefixArch));
 
-    if (!this->programDebug.isEmpty())
+    if (!this->programDebug.isEmpty()){
         env.append(QString(" WINEDEBUG='%1' ").arg(this->programDebug));
+    } else {
+        if ((!this->useConsole) && (CoreLib->getSetting("logging", "enable", false, 0).toInt()==0)){
+                env.append(QString(" WINEDEBUG='-all' "));
+        }
+    }
 
     if (!this->programDisplay.isEmpty())
         env.append(QString(" DISPLAY='%1' ").arg(this->programDisplay));
@@ -140,7 +157,13 @@ QString WineObject::createEnvString(){
 }
 
 int WineObject::runSys(){
-    bool logEnabled = false;
+
+    if (!this->useConsole){
+        int ret = this->runScript(this->prerun_script);
+        if ( ret != 0){
+            return 255;
+        }
+    }
 
     QString env = this->createEnvString();
     QString stdout, app_stdout;
@@ -151,44 +174,55 @@ int WineObject::runSys(){
     int status;
     char path[PATH_MAX];
 
-    QString run_string="";
-
+    QString run_string=this->prefixRunString;
     /*
      * We need to trim wrk dir path from binary path
      */
     this->programBinary = this->programBinary.replace(this->programWrkDir, "").replace("/", "");
 
-    if (!env.isEmpty()){
-        run_string.append(" env ");
-        run_string.append(env);
-    }
-
     if (this->useConsole){
+        // Owerride " with \" in case of using console app.
+        run_string.replace("\"", "\\\"");
         // If we gona use console output, so exec program is program specificed at CONSOLE global variable
-        run_string.append(QString(" %1 ").arg(CoreLib->getSetting("console", "bin").toString()));
+        QString console_bin = CoreLib->getSetting("console", "bin").toString();
+        QString console_args = CoreLib->getSetting("console", "args", false).toString();
 
-        if (!CoreLib->getSetting("console", "args", false).toString().isEmpty()){
-            // If we have any conslope parametres, we gona preccess them one by one
-            run_string.append(CoreLib->getSetting("console", "args", false).toString());
+        if (console_bin.split("/").last() == "konsole"){
+            console_args.append(" /bin/sh -c ");
         }
+
+        run_string.replace("%CONSOLE_BIN%", console_bin);
+        run_string.replace("%CONSOLE_ARGS%", QString("%1 \"").arg(console_args));
+    } else {
+        run_string.replace("%CONSOLE_BIN%", "");
+        run_string.replace("%CONSOLE_ARGS%", "");
     }
 
-    run_string.append(" /bin/sh -c \"");
+    if (!env.isEmpty()){
+        run_string.replace("%ENV_BIN%", "env");
+        run_string.replace("%ENV_ARGS%", env);
+    } else {
+        run_string.replace("%ENV_BIN%", "");
+        run_string.replace("%ENV_ARGS%", "");
+    }
 
     if (!this->programWrkDir.isEmpty()){
-        run_string.append(QString(" cd \'%1\' && ").arg(this->programWrkDir));
+        run_string.replace("%WORK_DIR%", QString("cd \'%1\' &&").arg(this->programWrkDir));
+    } else {
+        run_string.replace("%WORK_DIR%", "");
     }
 
     if (this->programNice != 0){
-        run_string.append(QString(" %1 -n %2 ").arg(CoreLib->getSetting("system", "nice", false).toString()).arg(this->programNice));
+        run_string.replace("%SET_NICE%", QString("%1 -n %2").arg(CoreLib->getSetting("system", "nice", false).toString()).arg(this->programNice));
+    } else {
+        run_string.replace("%SET_NICE%", "");
     }
 
-
     if (this->programBinary=="wineserver"){
-        run_string.append(QString(" %1server ").arg(this->prefixBinary));
+        run_string.replace("%WINE_BIN%", QString(" '%1server' ").arg(this->prefixBinary));
     } else {
-        run_string.append(QString(" %1 ").arg(this->prefixBinary));
-}
+        run_string.replace("%WINE_BIN%", QString(" '%1' ").arg(this->prefixBinary));
+    }
 
     if (!this->programDesktop.isEmpty()){
         QString deskname = this->programBinaryName;
@@ -210,97 +244,28 @@ int WineObject::runSys(){
         deskname.replace("/", ".");
         deskname.replace(">", ".");
         deskname.replace("<", ".");
-        run_string.append(QString(" explorer.exe /desktop=%1,%2 ").arg(deskname).arg(this->programDesktop));
+        run_string.replace("%VIRTUAL_DESKTOP%", QString(" explorer.exe /desktop=%1,%2 ").arg(deskname).arg(this->programDesktop));
+    } else {
+        run_string.replace("%VIRTUAL_DESKTOP%", "");
     }
 
     if (this->programBinary=="wineserver"){
-            run_string.append(QString(" %2 ").arg(programArgs));
+        run_string.replace("%PROGRAM_BIN%", "");
+        run_string.replace("%PROGRAM_ARGS%", programArgs);
     } else {
-        run_string.append(QString(" \'%1\' %2 ").arg(this->programBinary).arg(programArgs));
+        run_string.replace("%PROGRAM_BIN%", QString("\'%1\'").arg(this->programBinary));
+        run_string.replace("%PROGRAM_ARGS%", programArgs);
     }
-    run_string.append(" 2>&1 \"");
 
- /*   QStringList argss;
-    argss<<"-c"<<run_string;
-
-    QProcess *proc = new QProcess(0);
-    proc->start("/bin/sh", argss);
-
-    if (!proc->waitForStarted(90000))
-             return -1;
-    return 0;*/
-    /*
     if (this->useConsole){
-        // If we gona use console output, so exec program is program specificed at CONSOLE global variable
-        run_string = QString(" %1 ").arg(CoreLib->getSetting("console", "bin").toString());
-
-        if (!CoreLib->getSetting("console", "args", false).toString().isEmpty()){
-            // If we have any conslope parametres, we gona preccess them one by one
-            run_string.append(CoreLib->getSetting("console", "args", false).toString());
-        }
-
-        run_string.append(" /bin/sh -c \"cd \'");
-        run_string.append(this->programWrkDir);
-        run_string.append("\' && ");
-    } else {
-        if (chdir(codec->fromUnicode(this->programWrkDir).data()) != 0){
-            qDebug()<<"[EE] chdir to:"<<codec->fromUnicode(this->programWrkDir).data()<<"fail";
-            return -1;
-        } else {
-            qDebug()<<"wooot";
-        }
+        run_string.append("\"");
     }
 
-    //Setting enveropment variables
-    if (!env.isEmpty()){
-        run_string.append(" env ");
-        run_string.append(env);
-    }
-
-    if (this->programNice != 0){
-        run_string.append(QString(" %1 -n %2 ").arg(CoreLib->getSetting("system", "nice", false).toString()).arg(this->programNice));
-    }
-
-    run_string.append(QString(" %1 ").arg(this->prefixBinary));
-
-    if (!this->programDesktop.isEmpty()){
-        QString deskname = this->programBinaryName;
-        deskname.replace(" ", ".");
-        deskname.replace("&", ".");
-        deskname.replace("!", ".");
-        deskname.replace("$", ".");
-        deskname.replace("*", ".");
-        deskname.replace("(", ".");
-        deskname.replace(")", ".");
-        deskname.replace("[", ".");
-        deskname.replace("]", ".");
-        deskname.replace(";", ".");
-        deskname.replace("'", ".");
-        deskname.replace("\"", ".");
-        deskname.replace("|", ".");
-        deskname.replace("`", ".");
-        deskname.replace("\\", ".");
-        deskname.replace("/", ".");
-        deskname.replace(">", ".");
-        deskname.replace("<", ".");
-        run_string.append(QString(" explorer.exe /desktop=%1,%2 ").arg(deskname).arg(this->programDesktop));
-    }
-
-    run_string.append(QString(" \"%1\" %2 ").arg(this->programBinary).arg(programArgs));
-    run_string.append(" 2>&1 ");
-
-     if (this->useConsole){
-         run_string.append(" \"");
-     }
-    */
-
 #ifdef DEBUG
-    qDebug()<<run_string;
+    qDebug()<<"Template string: "<<this->prefixRunString;
+    qDebug()<<"Exec string    : "<<run_string;
 #endif
     stdout.append("Exec string:");
-    stdout.append("\n");
-    stdout.append(run_string.trimmed());
-    stdout.append("\n");
 
     fp = popen(codec->fromUnicode(run_string).data(), "r");
     if (fp == NULL){
@@ -310,9 +275,12 @@ int WineObject::runSys(){
             this->sendMessage(QString("console/%1/%2").arg(this->programBinaryName).arg(this->prefixName));
         } else {
             this->sendMessage(QString("start/%1/%2").arg(this->programBinaryName).arg(this->prefixName));
-        }
+        }    stdout.append("\n");
+        stdout.append(run_string.trimmed());
+        stdout.append("\n");
+
     }
-        /* Handle error */;
+    /* Handle error */;
 
     while (fgets(path, PATH_MAX, fp) != NULL){
         app_stdout.append(codec->toUnicode(path));
@@ -320,10 +288,11 @@ int WineObject::runSys(){
 
     status = pclose(fp);
 
-    if (CoreLib->getSetting("logging", "enable", false, 0).toInt()==1)
-        logEnabled = true;
-
-
+    if (!this->useConsole){
+        int ret = this->runScript(this->postrun_script);
+        if (ret != 0)
+            return ret;
+    }
 
     stdout.append("Exit code:");
     stdout.append("\n");
@@ -341,7 +310,7 @@ int WineObject::runSys(){
         this->sendMessage(QString("finish/%1/%2/%3").arg(this->programBinaryName).arg(this->prefixName).arg(status));
     } else {
         if (status!=0){
-            if (logEnabled){
+            if (this->logEnabled){
                 uint date = QDateTime::currentDateTime ().toTime_t();
                 db_logging.addLogRecord(this->prefixId, this->programBinaryName, status, stdout, date);
             }
@@ -352,16 +321,61 @@ int WineObject::runSys(){
     if (status>0){
         QTextStream QErr(stderr);
         QErr<<stdout;
-
         status=-1;
     }
 
     return status;
 }
 
+int WineObject::runScript(QString script_path){
+    int status;
+    FILE *fp;
+    char path[PATH_MAX];
+    QString stdout, app_stdout;
+
+    QString env = this->createEnvString();
+    QTextCodec *codec = QTextCodec::codecForName(CoreLib->getLocale().toAscii());
+
+    QString run_string = "";
+    if (!env.isEmpty()){
+        run_string.append(" env ");
+        run_string.append(env);
+    }
+
+    run_string.append(" /bin/sh -c \"");
+    run_string.append(script_path);
+    run_string.append("\" 2>&1");
+
+    fp = popen(codec->fromUnicode(run_string).data(), "r");
+    if (fp == NULL)
+        return 255;
+
+    while (fgets(path, PATH_MAX, fp) != NULL){
+        app_stdout.append(codec->toUnicode(path));
+    }
+
+    status = pclose(fp);
+    if (status != 0){
+        if (this->logEnabled){
+            stdout.append("Exit code:");
+            stdout.append("\n");
+            stdout.append(QString("%1").arg(status));
+            stdout.append("\n");
+            stdout.append("App STDOUT and STDERR output:");
+            stdout.append("\n");
+            stdout.append(app_stdout);
+
+            uint date = QDateTime::currentDateTime().toTime_t();
+            db_logging.addLogRecord(this->prefixId, this->programBinaryName, status, stdout, date);
+        }
+        this->sendMessage(QString("finish/%1/%2/%3").arg(this->programBinaryName).arg(this->prefixName).arg(status));
+    }
+    return status;
+}
+
 void WineObject::sendMessage(QString message){
     QLocalSocket socket(this);
-    socket.connectToServer( QString("/tmp/q4wine-%1.sock").arg(this->user) , QIODevice::WriteOnly );
+    socket.connectToServer( QString("/tmp/q4wine-%1.sock").arg(getuid()) , QIODevice::WriteOnly );
 
     if (socket.waitForConnected()){
 #ifdef DEBUG
@@ -392,3 +406,4 @@ void WineObject::sendMessage(QString message){
 void WineObject::setOverrideDll(QString dll_list){
     this->overrideDllList = dll_list;
 }
+
