@@ -38,7 +38,13 @@
 #include <sys/types.h>
 #include <fcntl.h>
 
-#define WTF_MAX 8192
+// Fix for GNU/Hurd, see:
+// https://www.gnu.org/software/hurd/community/gsoc/project_ideas/maxpath.html
+// http://insanecoding.blogspot.com/2007/11/pathmax-simply-isnt.html
+// The same limitation as in Linux is used here (see <linux/limits.h>):
+#ifdef __GNU__
+#define PATH_MAX 4096
+#endif
 
 class WineObject : public QObject
 {
@@ -57,12 +63,16 @@ public:
     void setProgramOverride(QString override);
     void setProgramWrkdir(QString wrkdir);
     void setProgramLang(QString lang);
+    void setPreRun(QString path);
+    void setPostRun(QString path);
 
     void setUseConsole(int console);
     void setOverrideDll(QString dll_list);
 
     int runSys();
 
+    int runScript(QString script_path);
+
 private:
 
     //! This is need for libq4wine-core.so import;
@@ -85,6 +95,7 @@ private:
     QString prefixLoader;
     QString prefixServer;
     QString prefixBinary;
+    QString prefixRunString;
 
     QString programBinary;
     QString programBinaryName;
@@ -98,9 +109,10 @@ private:
 
     QString programLang;
 
-    bool useConsole;
+    QString prerun_script;
+    QString postrun_script;
 
-    char *user;
+    bool useConsole, logEnabled;
 
 signals:
 
