@@ -19,14 +19,13 @@
 
 /*!
  * \defgroup libq4wine libq4wine-core
- * \brief libq4wine-core pakage provide general functions for q4wine-gui and q4wine-cli pakages.
+ * \brief libq4wine-core package provides general functions for q4wine-gui and q4wine-cli packages.
  */
 
 #ifndef Q4WINELIB_H
 #define Q4WINELIB_H
 
 #include "config.h"
-
 #include <QObject>
 #include <QList>
 #include <QVariant>
@@ -64,16 +63,22 @@
 
 // Experimental Darwin support (no test were preformed)
 #ifdef _OS_DARWIN_
-        #include <fcntl.h>
-        #include <paths.h>
 
-        #include <sys/param.h>
-        #include <sys/user.h>
-        #include <sys/file.h>
-        #include <sys/sysctl.h>
-        #include <limits.h>
+#include <sys/queue.h>
+
+#include <mach/mach.h>
+#include <mach/mach_error.h>
+#include <mach/policy.h>
+#include <mach/task_info.h>
+#include <mach/thread_info.h>
+#include <sys/sysctl.h>
+#include <sys/resourcevar.h>
+
+#include "src/darwin/ps.h"
+
 #endif
 
+
 #include "prefix.h"
 #include "dir.h"
 #include "icon.h"
@@ -82,10 +87,10 @@
 /*!
  * \class corelib
  * \ingroup libq4wine
- * \brief This class provide general core functions for q4wine.
+ * \brief This class provides general core functions for Q4Wine.
  *
  * It is not useful by itself, but helps to create user-side applications which
- * can use q4wine core functions;
+ * can use Q4Wine core functions;
  *
  */
 
@@ -104,6 +109,8 @@ struct ExecObject{
     QString nice;
     QString name;
     QString lang;
+    QString prerun;
+    QString postrun;
 };
 
 class corelib {
@@ -115,7 +122,7 @@ public:
      *
      * It gets process values: pid, name, nice priority and WINEPREFIX environment variable
      * \note On Linux it uses /proc file system, and on FreeBSD/MacOS it uses /dev/kmem and kvm.h functions.
-     * \return Return an array of QList which contains an QStringList
+     * \return Return an array of QList which contains a QStringList
      */
     QList<QStringList> getWineProcessList(const QString prefix_name = "");
 
@@ -139,7 +146,7 @@ public:
     QString getLocale();
 
     bool isConfigured();
-    bool checkDirs();
+    bool checkDirs(QString rootPath, QStringList subDirs = QStringList());
 
     void getBuildFlags();
 
@@ -153,6 +160,7 @@ public:
      * \return Return the full path of binary.
      */
     QString getWhichOut (const QString fileName, bool showErr = TRUE);
+    QStringList getWineLibsPath(void);
 
     /*! \brief This function get cdrom devices from /etc/fstab file.
      *
@@ -235,7 +243,8 @@ public:
     bool checkFileExists(QString path);
 
 
-    QString createDesktopFile(const QString prefix_name, const QString dir_name, const QString icon_name) const;
+    QString createDesktopFile(const QString prefix_name, const QString dir_name, const QString icon_name, const bool is_menu = false) const;
+    bool deleteDesktopFile(const QString prefix_name, const QString dir_name, const QString icon_name) const;
 
     QString getWinePath(const QString path, const QString option);
 
@@ -292,7 +301,7 @@ public:
 
     /*! \brief This function is used to export prefix info.
      *
-     * This function will export q4wine prefixes information according with http://wiki.winehq.org/BottleSpec
+     * This function will export Q4Wine prefixes information according with http://wiki.winehq.org/BottleSpec
      *
      * \return true on success.
      */
@@ -306,6 +315,14 @@ public:
      */
     QStringList importPrefixesConfiguration(void);
 
+    /*! \brief This function is used to remove directory.
+     *
+     * This function is used to remove directory
+     *
+     * \return true on success.
+     */
+    bool removeDirectory(QString dirPath);
+
 private:
     /*! Define is library operate in CLI or GUI mode.
      * \note This is typically need for error message display.
